
################################################################
# This is a generated script based on design: hio
#
# Though there are limitations about the generated script,
# the main purpose of this utility is to make learning
# IP Integrator Tcl commands easier.
################################################################

################################################################
# Check if script is running in correct Vivado version.
################################################################
set scripts_vivado_version 2015.4
set current_vivado_version [version -short]

if { [string first $scripts_vivado_version $current_vivado_version] == -1 } {
   puts ""
   puts "ERROR: This script was generated using Vivado <$scripts_vivado_version> and is being run in <$current_vivado_version> of Vivado. Please run the script in Vivado <$scripts_vivado_version> then open the design in Vivado <$current_vivado_version>. Upgrade the design by running \"Tools => Report => Report IP Status...\", then run write_bd_tcl to create an updated script."

   return 1
}

################################################################
# START
################################################################

# To test this script, run the following commands from Vivado Tcl console:
# source hio_script.tcl

# If you do not already have a project created,
# you can create a project using the following command:
#    create_project project_1 myproj -part xc7z020clg484-2
#    set_property BOARD_PART trenz.biz:te0720-02-2if:part0:1.0 [current_project]

# CHECKING IF PROJECT EXISTS
if { [get_projects -quiet] eq "" } {
   puts "ERROR: Please open or create a project!"
   return 1
}



# CHANGE DESIGN NAME HERE
set design_name hio

# If you do not already have an existing IP Integrator design open,
# you can create a design using the following command:
#    create_bd_design $design_name

# Creating design if needed
set errMsg ""
set nRet 0

set cur_design [current_bd_design -quiet]
set list_cells [get_bd_cells -quiet]

if { ${design_name} eq "" } {
   # USE CASES:
   #    1) Design_name not set

   set errMsg "ERROR: Please set the variable <design_name> to a non-empty value."
   set nRet 1

} elseif { ${cur_design} ne "" && ${list_cells} eq "" } {
   # USE CASES:
   #    2): Current design opened AND is empty AND names same.
   #    3): Current design opened AND is empty AND names diff; design_name NOT in project.
   #    4): Current design opened AND is empty AND names diff; design_name exists in project.

   if { $cur_design ne $design_name } {
      puts "INFO: Changing value of <design_name> from <$design_name> to <$cur_design> since current design is empty."
      set design_name [get_property NAME $cur_design]
   }
   puts "INFO: Constructing design in IPI design <$cur_design>..."

} elseif { ${cur_design} ne "" && $list_cells ne "" && $cur_design eq $design_name } {
   # USE CASES:
   #    5) Current design opened AND has components AND same names.

   set errMsg "ERROR: Design <$design_name> already exists in your project, please set the variable <design_name> to another value."
   set nRet 1
} elseif { [get_files -quiet ${design_name}.bd] ne "" } {
   # USE CASES: 
   #    6) Current opened design, has components, but diff names, design_name exists in project.
   #    7) No opened design, design_name exists in project.

   set errMsg "ERROR: Design <$design_name> already exists in your project, please set the variable <design_name> to another value."
   set nRet 2

} else {
   # USE CASES:
   #    8) No opened design, design_name not in project.
   #    9) Current opened design, has components, but diff names, design_name not in project.

   puts "INFO: Currently there is no design <$design_name> in project, so creating one..."

   create_bd_design $design_name

   puts "INFO: Making design <$design_name> as current_bd_design."
   current_bd_design $design_name

}

puts "INFO: Currently the variable <design_name> is equal to \"$design_name\"."

if { $nRet != 0 } {
   puts $errMsg
   return $nRet
}

##################################################################
# DESIGN PROCs
##################################################################


# Hierarchical cell: python1300_receiver_color
proc create_hier_cell_python1300_receiver_color { parentCell nameHier } {

  if { $parentCell eq "" || $nameHier eq "" } {
     puts "ERROR: create_hier_cell_python1300_receiver_color() - Empty argument(s)!"
     return
  }

  # Get object for parentCell
  set parentObj [get_bd_cells $parentCell]
  if { $parentObj == "" } {
     puts "ERROR: Unable to find parent cell <$parentCell>!"
     return
  }

  # Make sure parentObj is hier blk
  set parentType [get_property TYPE $parentObj]
  if { $parentType ne "hier" } {
     puts "ERROR: Parent <$parentObj> has TYPE = <$parentType>. Expected to be <hier>."
     return
  }

  # Save current instance; Restore later
  set oldCurInst [current_bd_instance .]

  # Set parent object as current
  current_bd_instance $parentObj

  # Create cell and set as current instance
  set hier_obj [create_bd_cell -type hier $nameHier]
  current_bd_instance $hier_obj

  # Create interface pins
  create_bd_intf_pin -mode Slave -vlnv avnet.com:interface:onsemi_vita_cam_rtl:1.0 IO_CAM_IN
  create_bd_intf_pin -mode Slave -vlnv xilinx.com:interface:aximm_rtl:1.0 S00_AXI
  create_bd_intf_pin -mode Master -vlnv xilinx.com:interface:axis_rtl:1.0 video_out

  # Create pins
  create_bd_pin -dir I -type clk aclk
  create_bd_pin -dir I -from 0 -to 0 -type rst aresetn
  create_bd_pin -dir I clk
  create_bd_pin -dir I clk200
  create_bd_pin -dir I -from 0 -to 0 -type rst reset
  create_bd_pin -dir I -type clk s00_axi_aclk
  create_bd_pin -dir I -from 0 -to 0 -type rst s00_axi_aresetn

  # Create instance: onsemi_vita_cam_0, and set properties
  set onsemi_vita_cam_0 [ create_bd_cell -type ip -vlnv avnet:onsemi_vita:onsemi_vita_cam:3.2 onsemi_vita_cam_0 ]

  # Create instance: v_cfa_0, and set properties
  set v_cfa_0 [ create_bd_cell -type ip -vlnv xilinx.com:ip:v_cfa:7.0 v_cfa_0 ]
  set_property -dict [ list \
CONFIG.active_cols {1280} \
CONFIG.active_rows {1024} \
CONFIG.bayer_phase {0} \
CONFIG.hor_filt {true} \
CONFIG.max_cols {1280} \
 ] $v_cfa_0

  # Create instance: v_cresample_0, and set properties
  set v_cresample_0 [ create_bd_cell -type ip -vlnv xilinx.com:ip:v_cresample:4.0 v_cresample_0 ]
  set_property -dict [ list \
CONFIG.active_cols {1280} \
CONFIG.active_rows {1024} \
CONFIG.m_axis_video_format {2} \
CONFIG.max_cols {1280} \
CONFIG.num_h_taps {3} \
CONFIG.num_v_taps {0} \
CONFIG.s_axis_video_format {3} \
 ] $v_cresample_0

  # Create instance: v_rgb2ycrcb_0, and set properties
  set v_rgb2ycrcb_0 [ create_bd_cell -type ip -vlnv xilinx.com:ip:v_rgb2ycrcb:7.1 v_rgb2ycrcb_0 ]
  set_property -dict [ list \
CONFIG.ACTIVE_COLS {1280} \
CONFIG.ACTIVE_ROWS {1024} \
CONFIG.Output_Range {0_to_255_for_Computer_Graphics} \
CONFIG.Standard_Sel {HD_ITU_709__1125_NTSC} \
CONFIG.acoef {0.2568} \
CONFIG.bcoef {0.0979} \
CONFIG.cbmax {255} \
CONFIG.cbmin {0} \
CONFIG.ccoef {0.591} \
CONFIG.crmax {255} \
CONFIG.crmin {0} \
CONFIG.dcoef {0.5772} \
CONFIG.ymax {255} \
CONFIG.ymin {0} \
 ] $v_rgb2ycrcb_0

  # Create instance: v_vid_in_axi4s_0, and set properties
  set v_vid_in_axi4s_0 [ create_bd_cell -type ip -vlnv xilinx.com:ip:v_vid_in_axi4s:4.0 v_vid_in_axi4s_0 ]
  set_property -dict [ list \
CONFIG.C_ADDR_WIDTH {12} \
CONFIG.C_HAS_ASYNC_CLK {1} \
CONFIG.C_M_AXIS_VIDEO_FORMAT {12} \
 ] $v_vid_in_axi4s_0

  # Create interface connections
  connect_bd_intf_net -intf_net IO_CAM_IN_1 [get_bd_intf_pins IO_CAM_IN] [get_bd_intf_pins onsemi_vita_cam_0/IO_CAM_IN]
  connect_bd_intf_net -intf_net onsemi_vita_cam_0_VID_IO_OUT [get_bd_intf_pins onsemi_vita_cam_0/VID_IO_OUT] [get_bd_intf_pins v_vid_in_axi4s_0/vid_io_in]
  connect_bd_intf_net -intf_net processing_system7_0_axi_periph_M05_AXI [get_bd_intf_pins S00_AXI] [get_bd_intf_pins onsemi_vita_cam_0/S00_AXI]
  connect_bd_intf_net -intf_net v_cfa_0_video_out [get_bd_intf_pins v_cfa_0/video_out] [get_bd_intf_pins v_rgb2ycrcb_0/video_in]
  connect_bd_intf_net -intf_net v_cresample_0_video_out [get_bd_intf_pins video_out] [get_bd_intf_pins v_cresample_0/video_out]
  connect_bd_intf_net -intf_net v_rgb2ycrcb_0_video_out [get_bd_intf_pins v_cresample_0/video_in] [get_bd_intf_pins v_rgb2ycrcb_0/video_out]
  connect_bd_intf_net -intf_net v_vid_in_axi4s_0_video_out [get_bd_intf_pins v_cfa_0/video_in] [get_bd_intf_pins v_vid_in_axi4s_0/video_out]

  # Create port connections
  connect_bd_net -net axis_resetn_1 [get_bd_pins aresetn] [get_bd_pins v_cfa_0/aresetn] [get_bd_pins v_cresample_0/aresetn] [get_bd_pins v_rgb2ycrcb_0/aresetn] [get_bd_pins v_vid_in_axi4s_0/aresetn]
  connect_bd_net -net clk_1 [get_bd_pins clk] [get_bd_pins onsemi_vita_cam_0/clk] [get_bd_pins v_vid_in_axi4s_0/vid_io_in_clk]
  connect_bd_net -net clk_wiz_1_clk_out1 [get_bd_pins aclk] [get_bd_pins v_cfa_0/aclk] [get_bd_pins v_cresample_0/aclk] [get_bd_pins v_rgb2ycrcb_0/aclk] [get_bd_pins v_vid_in_axi4s_0/aclk]
  connect_bd_net -net proc_sys_reset_50MHz_peripheral_aresetn [get_bd_pins s00_axi_aresetn] [get_bd_pins onsemi_vita_cam_0/s00_axi_aresetn]
  connect_bd_net -net processing_system7_0_FCLK_CLK0 [get_bd_pins s00_axi_aclk] [get_bd_pins onsemi_vita_cam_0/s00_axi_aclk]
  connect_bd_net -net processing_system7_0_FCLK_CLK1 [get_bd_pins clk200] [get_bd_pins onsemi_vita_cam_0/clk200]
  connect_bd_net -net reset_1 [get_bd_pins reset] [get_bd_pins onsemi_vita_cam_0/reset] [get_bd_pins v_vid_in_axi4s_0/vid_io_in_reset]

  # Restore current instance
  current_bd_instance $oldCurInst
}

# Hierarchical cell: imageon_hdmi_out
proc create_hier_cell_imageon_hdmi_out { parentCell nameHier } {

  if { $parentCell eq "" || $nameHier eq "" } {
     puts "ERROR: create_hier_cell_imageon_hdmi_out() - Empty argument(s)!"
     return
  }

  # Get object for parentCell
  set parentObj [get_bd_cells $parentCell]
  if { $parentObj == "" } {
     puts "ERROR: Unable to find parent cell <$parentCell>!"
     return
  }

  # Make sure parentObj is hier blk
  set parentType [get_property TYPE $parentObj]
  if { $parentType ne "hier" } {
     puts "ERROR: Parent <$parentObj> has TYPE = <$parentType>. Expected to be <hier>."
     return
  }

  # Save current instance; Restore later
  set oldCurInst [current_bd_instance .]

  # Set parent object as current
  current_bd_instance $parentObj

  # Create cell and set as current instance
  set hier_obj [create_bd_cell -type hier $nameHier]
  current_bd_instance $hier_obj

  # Create interface pins
  create_bd_intf_pin -mode Slave -vlnv xilinx.com:interface:axis_rtl:1.0 AXIS_vid_in
  create_bd_intf_pin -mode Slave -vlnv xilinx.com:interface:aximm_rtl:1.0 AXI_lite
  create_bd_intf_pin -mode Master -vlnv avnet.com:interface:avnet_hdmi_rtl:1.0 HDMI_vid_out

  # Create pins
  create_bd_pin -dir I -type clk axi_lite_clk
  create_bd_pin -dir I -from 0 -to 0 -type rst axi_lite_resetn
  create_bd_pin -dir I -type clk axis_clk
  create_bd_pin -dir I -from 0 -to 0 -type rst axis_resetn
  create_bd_pin -dir I vid_out_clk

  # Create instance: fmc_imageon_hdmi_out_0, and set properties
  set fmc_imageon_hdmi_out_0 [ create_bd_cell -type ip -vlnv avnet:fmc_imageon:fmc_imageon_hdmi_out:2.0 fmc_imageon_hdmi_out_0 ]

  # Create instance: gnd, and set properties
  set gnd [ create_bd_cell -type ip -vlnv xilinx.com:ip:xlconstant:1.1 gnd ]
  set_property -dict [ list \
CONFIG.CONST_VAL {0} \
 ] $gnd

  # Create instance: v_axi4s_vid_out_0, and set properties
  set v_axi4s_vid_out_0 [ create_bd_cell -type ip -vlnv xilinx.com:ip:v_axi4s_vid_out:4.0 v_axi4s_vid_out_0 ]
  set_property -dict [ list \
CONFIG.C_ADDR_WIDTH {12} \
CONFIG.C_HAS_ASYNC_CLK {1} \
CONFIG.C_HYSTERESIS_LEVEL {3072} \
CONFIG.C_S_AXIS_VIDEO_FORMAT {0} \
CONFIG.C_VTG_MASTER_SLAVE {1} \
 ] $v_axi4s_vid_out_0

  # Create instance: v_tc_0, and set properties
  set v_tc_0 [ create_bd_cell -type ip -vlnv xilinx.com:ip:v_tc:6.1 v_tc_0 ]
  set_property -dict [ list \
CONFIG.VIDEO_MODE {1080p} \
CONFIG.auto_generation_mode {false} \
CONFIG.enable_detection {false} \
CONFIG.enable_generation {true} \
CONFIG.horizontal_sync_detection {true} \
CONFIG.vertical_sync_detection {true} \
 ] $v_tc_0

  # Create instance: vcc, and set properties
  set vcc [ create_bd_cell -type ip -vlnv xilinx.com:ip:xlconstant:1.1 vcc ]

  # Create interface connections
  connect_bd_intf_net -intf_net AXIS_vid_in_1 [get_bd_intf_pins AXIS_vid_in] [get_bd_intf_pins v_axi4s_vid_out_0/video_in]
  connect_bd_intf_net -intf_net fmc_imageon_hdmi_out_0_IO_HDMIO [get_bd_intf_pins HDMI_vid_out] [get_bd_intf_pins fmc_imageon_hdmi_out_0/IO_HDMIO]
  connect_bd_intf_net -intf_net processing_system7_0_axi_periph_M01_AXI [get_bd_intf_pins AXI_lite] [get_bd_intf_pins v_tc_0/ctrl]
  connect_bd_intf_net -intf_net v_axi4s_vid_out_0_vid_io_out [get_bd_intf_pins fmc_imageon_hdmi_out_0/VID_IO_IN] [get_bd_intf_pins v_axi4s_vid_out_0/vid_io_out]
  connect_bd_intf_net -intf_net v_tc_0_vtiming_out [get_bd_intf_pins v_axi4s_vid_out_0/vtiming_in] [get_bd_intf_pins v_tc_0/vtiming_out]

  # Create port connections
  connect_bd_net -net clkgen_150_MHz_clk_out1 [get_bd_pins axis_clk] [get_bd_pins v_axi4s_vid_out_0/aclk]
  connect_bd_net -net gnd_dout [get_bd_pins fmc_imageon_hdmi_out_0/reset] [get_bd_pins gnd/dout] [get_bd_pins v_axi4s_vid_out_0/vid_io_out_reset]
  connect_bd_net -net processing_system7_0_FCLK_CLK0 [get_bd_pins axi_lite_clk] [get_bd_pins v_tc_0/s_axi_aclk]
  connect_bd_net -net rst_processing_system7_0_50M_peripheral_aresetn [get_bd_pins axi_lite_resetn] [get_bd_pins v_tc_0/s_axi_aresetn]
  connect_bd_net -net rst_sync_to_axis_clk_peripheral_aresetn [get_bd_pins axis_resetn] [get_bd_pins v_axi4s_vid_out_0/aresetn]
  connect_bd_net -net util_ds_buf_0_IBUF_OUT [get_bd_pins vid_out_clk] [get_bd_pins fmc_imageon_hdmi_out_0/clk] [get_bd_pins v_axi4s_vid_out_0/vid_io_out_clk] [get_bd_pins v_tc_0/clk]
  connect_bd_net -net v_axi4s_vid_out_0_locked [get_bd_pins fmc_imageon_hdmi_out_0/oe] [get_bd_pins v_axi4s_vid_out_0/locked]
  connect_bd_net -net v_axi4s_vid_out_0_vtg_ce [get_bd_pins v_axi4s_vid_out_0/vtg_ce] [get_bd_pins v_tc_0/gen_clken]
  connect_bd_net -net vcc_dout [get_bd_pins fmc_imageon_hdmi_out_0/embed_syncs] [get_bd_pins v_axi4s_vid_out_0/aclken] [get_bd_pins v_axi4s_vid_out_0/vid_io_out_ce] [get_bd_pins v_tc_0/clken] [get_bd_pins v_tc_0/resetn] [get_bd_pins v_tc_0/s_axi_aclken] [get_bd_pins vcc/dout]

  # Restore current instance
  current_bd_instance $oldCurInst
}


# Procedure to create entire design; Provide argument to make
# procedure reusable. If parentCell is "", will use root.
proc create_root_design { parentCell } {

  if { $parentCell eq "" } {
     set parentCell [get_bd_cells /]
  }

  # Get object for parentCell
  set parentObj [get_bd_cells $parentCell]
  if { $parentObj == "" } {
     puts "ERROR: Unable to find parent cell <$parentCell>!"
     return
  }

  # Make sure parentObj is hier blk
  set parentType [get_property TYPE $parentObj]
  if { $parentType ne "hier" } {
     puts "ERROR: Parent <$parentObj> has TYPE = <$parentType>. Expected to be <hier>."
     return
  }

  # Save current instance; Restore later
  set oldCurInst [current_bd_instance .]

  # Set parent object as current
  current_bd_instance $parentObj


  # Create interface ports
  set DDR [ create_bd_intf_port -mode Master -vlnv xilinx.com:interface:ddrx_rtl:1.0 DDR ]
  set FIXED_IO [ create_bd_intf_port -mode Master -vlnv xilinx.com:display_processing_system7:fixedio_rtl:1.0 FIXED_IO ]
  set IO_PYTHON_CAM [ create_bd_intf_port -mode Slave -vlnv avnet.com:interface:onsemi_vita_cam_rtl:1.0 IO_PYTHON_CAM ]
  set IO_PYTHON_SPI [ create_bd_intf_port -mode Master -vlnv avnet.com:interface:onsemi_vita_spi_rtl:1.0 IO_PYTHON_SPI ]
  set fmc_hdmio_io [ create_bd_intf_port -mode Master -vlnv avnet.com:interface:avnet_hdmi_rtl:1.0 fmc_hdmio_io ]
  set fmc_imageon_iic [ create_bd_intf_port -mode Master -vlnv xilinx.com:interface:iic_rtl:1.0 fmc_imageon_iic ]

  # Create ports
  set fmc_imageon_iic_rst_n [ create_bd_port -dir O -from 0 -to 0 fmc_imageon_iic_rst_n ]
  set uart_pmod_rx [ create_bd_port -dir O uart_pmod_rx ]
  set uart_pmod_tx [ create_bd_port -dir I uart_pmod_tx ]

  # Create instance: axi_ic_processing_system7_0_M_AXI_GP1, and set properties
  set axi_ic_processing_system7_0_M_AXI_GP1 [ create_bd_cell -type ip -vlnv xilinx.com:ip:axi_interconnect:2.1 axi_ic_processing_system7_0_M_AXI_GP1 ]
  set_property -dict [ list \
CONFIG.M00_HAS_REGSLICE {1} \
CONFIG.M01_HAS_REGSLICE {1} \
CONFIG.M02_HAS_REGSLICE {1} \
CONFIG.NUM_MI {3} \
CONFIG.NUM_SI {1} \
CONFIG.S00_HAS_REGSLICE {1} \
CONFIG.STRATEGY {2} \
 ] $axi_ic_processing_system7_0_M_AXI_GP1

  # Create instance: axi_ic_processing_system7_0_S_AXI_HP2, and set properties
  set axi_ic_processing_system7_0_S_AXI_HP2 [ create_bd_cell -type ip -vlnv xilinx.com:ip:axi_interconnect:2.1 axi_ic_processing_system7_0_S_AXI_HP2 ]
  set_property -dict [ list \
CONFIG.M00_HAS_DATA_FIFO {2} \
CONFIG.M00_HAS_REGSLICE {1} \
CONFIG.NUM_MI {1} \
CONFIG.NUM_SI {2} \
CONFIG.S00_HAS_DATA_FIFO {2} \
CONFIG.S00_HAS_REGSLICE {1} \
CONFIG.S01_HAS_DATA_FIFO {2} \
CONFIG.S01_HAS_REGSLICE {1} \
CONFIG.STRATEGY {2} \
 ] $axi_ic_processing_system7_0_S_AXI_HP2

  # Create instance: axi_mem_intercon, and set properties
  set axi_mem_intercon [ create_bd_cell -type ip -vlnv xilinx.com:ip:axi_interconnect:2.1 axi_mem_intercon ]
  set_property -dict [ list \
CONFIG.ENABLE_ADVANCED_OPTIONS {1} \
CONFIG.M00_HAS_DATA_FIFO {2} \
CONFIG.NUM_MI {1} \
CONFIG.NUM_SI {2} \
CONFIG.S00_HAS_DATA_FIFO {2} \
CONFIG.S01_HAS_DATA_FIFO {2} \
CONFIG.STRATEGY {2} \
CONFIG.XBAR_DATA_WIDTH {64} \
 ] $axi_mem_intercon

  # Create instance: axi_mem_intercon_1, and set properties
  set axi_mem_intercon_1 [ create_bd_cell -type ip -vlnv xilinx.com:ip:axi_interconnect:2.1 axi_mem_intercon_1 ]
  set_property -dict [ list \
CONFIG.ENABLE_ADVANCED_OPTIONS {1} \
CONFIG.NUM_MI {1} \
CONFIG.NUM_SI {2} \
CONFIG.XBAR_DATA_WIDTH {64} \
 ] $axi_mem_intercon_1

  # Create instance: axi_timer_0, and set properties
  set axi_timer_0 [ create_bd_cell -type ip -vlnv xilinx.com:ip:axi_timer:2.0 axi_timer_0 ]

  # Create instance: axi_uartlite_0, and set properties
  set axi_uartlite_0 [ create_bd_cell -type ip -vlnv xilinx.com:ip:axi_uartlite:2.0 axi_uartlite_0 ]
  set_property -dict [ list \
CONFIG.C_BAUDRATE {115200} \
 ] $axi_uartlite_0

  # Create instance: axi_vdma_0, and set properties
  set axi_vdma_0 [ create_bd_cell -type ip -vlnv xilinx.com:ip:axi_vdma:6.2 axi_vdma_0 ]
  set_property -dict [ list \
CONFIG.c_m_axi_s2mm_data_width {64} \
CONFIG.c_m_axis_mm2s_tdata_width {16} \
CONFIG.c_mm2s_linebuffer_depth {4096} \
CONFIG.c_mm2s_max_burst_length {64} \
CONFIG.c_num_fstores {8} \
CONFIG.c_s2mm_linebuffer_depth {4096} \
CONFIG.c_s2mm_max_burst_length {64} \
 ] $axi_vdma_0

  # Create instance: bce_fp12_1x8_0_axiw_0, and set properties
  set bce_fp12_1x8_0_axiw_0 [ create_bd_cell -type ip -vlnv xilinx.com:user:bce_fp12_1x8_0_axiw:1.0 bce_fp12_1x8_0_axiw_0 ]

  # Create instance: bce_fp12_1x8_0_dsp_0, and set properties
  set bce_fp12_1x8_0_dsp_0 [ create_bd_cell -type ip -vlnv User_Company:SysGen:bce_fp12_1x8_0_dsp:1.0 bce_fp12_1x8_0_dsp_0 ]

  # Create instance: clk_wiz_1, and set properties
  set clk_wiz_1 [ create_bd_cell -type ip -vlnv xilinx.com:ip:clk_wiz:5.2 clk_wiz_1 ]
  set_property -dict [ list \
CONFIG.CLKIN1_JITTER_PS {200.0} \
CONFIG.CLKOUT1_JITTER {196.394} \
CONFIG.CLKOUT1_PHASE_ERROR {155.997} \
CONFIG.CLKOUT1_REQUESTED_OUT_FREQ {150} \
CONFIG.CLKOUT2_JITTER {206.371} \
CONFIG.CLKOUT2_PHASE_ERROR {155.997} \
CONFIG.CLKOUT2_REQUESTED_OUT_FREQ {120} \
CONFIG.CLKOUT2_USED {true} \
CONFIG.CLKOUT3_JITTER {214.854} \
CONFIG.CLKOUT3_PHASE_ERROR {155.997} \
CONFIG.CLKOUT3_USED {true} \
CONFIG.CLKOUT4_JITTER {228.642} \
CONFIG.CLKOUT4_PHASE_ERROR {155.997} \
CONFIG.CLKOUT4_REQUESTED_OUT_FREQ {75} \
CONFIG.CLKOUT4_USED {true} \
CONFIG.MMCM_CLKFBOUT_MULT_F {24.000} \
CONFIG.MMCM_CLKIN1_PERIOD {20.0} \
CONFIG.MMCM_CLKOUT0_DIVIDE_F {8.000} \
CONFIG.MMCM_CLKOUT1_DIVIDE {10} \
CONFIG.MMCM_CLKOUT2_DIVIDE {12} \
CONFIG.MMCM_CLKOUT3_DIVIDE {16} \
CONFIG.MMCM_DIVCLK_DIVIDE {1} \
CONFIG.NUM_OUT_CLKS {4} \
CONFIG.PRIM_IN_FREQ {50} \
CONFIG.RESET_PORT {resetn} \
CONFIG.RESET_TYPE {ACTIVE_LOW} \
 ] $clk_wiz_1

  # Create instance: clk_wiz_108MHz, and set properties
  set clk_wiz_108MHz [ create_bd_cell -type ip -vlnv xilinx.com:ip:clk_wiz:5.2 clk_wiz_108MHz ]
  set_property -dict [ list \
CONFIG.CLKOUT1_JITTER {157.008} \
CONFIG.CLKOUT1_PHASE_ERROR {162.874} \
CONFIG.CLKOUT1_REQUESTED_OUT_FREQ {108.000} \
CONFIG.MMCM_CLKFBOUT_MULT_F {20.250} \
CONFIG.MMCM_CLKOUT0_DIVIDE_F {9.375} \
CONFIG.MMCM_DIVCLK_DIVIDE {1} \
CONFIG.RESET_PORT {resetn} \
CONFIG.RESET_TYPE {ACTIVE_LOW} \
 ] $clk_wiz_108MHz

  # Create instance: dm_0, and set properties
  set dm_0 [ create_bd_cell -type ip -vlnv xilinx.com:ip:axi_dma:7.1 dm_0 ]
  set_property -dict [ list \
CONFIG.c_dlytmr_resolution {1250} \
CONFIG.c_include_mm2s {1} \
CONFIG.c_include_mm2s_dre {1} \
CONFIG.c_include_mm2s_sf {1} \
CONFIG.c_include_s2mm {0} \
CONFIG.c_include_sg {0} \
CONFIG.c_m_axi_mm2s_data_width {64} \
CONFIG.c_m_axis_mm2s_tdata_width {64} \
CONFIG.c_mm2s_burst_size {64} \
CONFIG.c_sg_length_width {23} \
 ] $dm_0

  # Create instance: dm_1, and set properties
  set dm_1 [ create_bd_cell -type ip -vlnv xilinx.com:ip:axi_dma:7.1 dm_1 ]
  set_property -dict [ list \
CONFIG.c_dlytmr_resolution {1250} \
CONFIG.c_include_mm2s {0} \
CONFIG.c_include_s2mm {1} \
CONFIG.c_include_s2mm_dre {1} \
CONFIG.c_include_s2mm_sf {1} \
CONFIG.c_include_sg {0} \
CONFIG.c_m_axi_s2mm_data_width {64} \
CONFIG.c_s2mm_burst_size {64} \
CONFIG.c_s_axis_s2mm_tdata_width {64} \
CONFIG.c_sg_length_width {23} \
 ] $dm_1

  # Create instance: fmc2_imageon_iic, and set properties
  set fmc2_imageon_iic [ create_bd_cell -type ip -vlnv xilinx.com:ip:axi_iic:2.0 fmc2_imageon_iic ]

  # Create instance: imageon_hdmi_out
  create_hier_cell_imageon_hdmi_out [current_bd_instance .] imageon_hdmi_out

  # Create instance: mdm_1, and set properties
  set mdm_1 [ create_bd_cell -type ip -vlnv xilinx.com:ip:mdm:3.2 mdm_1 ]

  # Create instance: microblaze_0, and set properties
  set microblaze_0 [ create_bd_cell -type ip -vlnv xilinx.com:ip:microblaze:9.5 microblaze_0 ]
  set_property -dict [ list \
CONFIG.C_BASE_VECTORS {0x30000000} \
CONFIG.C_CACHE_BYTE_SIZE {32768} \
CONFIG.C_DCACHE_BYTE_SIZE {32768} \
CONFIG.C_DCACHE_LINE_LEN {8} \
CONFIG.C_DCACHE_USE_WRITEBACK {1} \
CONFIG.C_DCACHE_VICTIMS {8} \
CONFIG.C_DEBUG_ENABLED {1} \
CONFIG.C_D_AXI {1} \
CONFIG.C_D_LMB {0} \
CONFIG.C_ICACHE_LINE_LEN {8} \
CONFIG.C_ICACHE_STREAMS {1} \
CONFIG.C_ICACHE_VICTIMS {8} \
CONFIG.C_I_LMB {0} \
CONFIG.C_MMU_ZONES {2} \
CONFIG.C_USE_BARREL {1} \
CONFIG.C_USE_BRANCH_TARGET_CACHE {1} \
CONFIG.C_USE_DCACHE {1} \
CONFIG.C_USE_DIV {1} \
CONFIG.C_USE_FPU {1} \
CONFIG.C_USE_HW_MUL {1} \
CONFIG.C_USE_ICACHE {1} \
CONFIG.C_USE_MSR_INSTR {1} \
CONFIG.C_USE_PCMP_INSTR {1} \
CONFIG.G_TEMPLATE_LIST {2} \
 ] $microblaze_0

  # Create instance: microblaze_0_axi_intc, and set properties
  set microblaze_0_axi_intc [ create_bd_cell -type ip -vlnv xilinx.com:ip:axi_intc:4.1 microblaze_0_axi_intc ]
  set_property -dict [ list \
CONFIG.C_HAS_FAST {1} \
 ] $microblaze_0_axi_intc

  # Create instance: microblaze_0_axi_periph, and set properties
  set microblaze_0_axi_periph [ create_bd_cell -type ip -vlnv xilinx.com:ip:axi_interconnect:2.1 microblaze_0_axi_periph ]
  set_property -dict [ list \
CONFIG.NUM_MI {5} \
 ] $microblaze_0_axi_periph

  # Create instance: microblaze_0_xlconcat, and set properties
  set microblaze_0_xlconcat [ create_bd_cell -type ip -vlnv xilinx.com:ip:xlconcat:2.1 microblaze_0_xlconcat ]
  set_property -dict [ list \
CONFIG.NUM_PORTS {2} \
 ] $microblaze_0_xlconcat

  # Create instance: mutex_0, and set properties
  set mutex_0 [ create_bd_cell -type ip -vlnv xilinx.com:ip:mutex:2.1 mutex_0 ]
  set_property -dict [ list \
CONFIG.C_ASYNC_CLKS {1} \
CONFIG.C_ENABLE_USER {1} \
CONFIG.C_NUM_MUTEX {4} \
CONFIG.C_S0_AXI_ACLK_FREQ_MHZ {50.0} \
 ] $mutex_0

  # Create instance: onsemi_python_spi_0, and set properties
  set onsemi_python_spi_0 [ create_bd_cell -type ip -vlnv avnet:onsemi_vita:onsemi_vita_spi:3.2 onsemi_python_spi_0 ]

  # Create instance: proc_sys_reset_100MHz, and set properties
  set proc_sys_reset_100MHz [ create_bd_cell -type ip -vlnv xilinx.com:ip:proc_sys_reset:5.0 proc_sys_reset_100MHz ]

  # Create instance: proc_sys_reset_108MHz, and set properties
  set proc_sys_reset_108MHz [ create_bd_cell -type ip -vlnv xilinx.com:ip:proc_sys_reset:5.0 proc_sys_reset_108MHz ]

  # Create instance: proc_sys_reset_120MHz, and set properties
  set proc_sys_reset_120MHz [ create_bd_cell -type ip -vlnv xilinx.com:ip:proc_sys_reset:5.0 proc_sys_reset_120MHz ]

  # Create instance: proc_sys_reset_150MHz, and set properties
  set proc_sys_reset_150MHz [ create_bd_cell -type ip -vlnv xilinx.com:ip:proc_sys_reset:5.0 proc_sys_reset_150MHz ]

  # Create instance: proc_sys_reset_50MHz, and set properties
  set proc_sys_reset_50MHz [ create_bd_cell -type ip -vlnv xilinx.com:ip:proc_sys_reset:5.0 proc_sys_reset_50MHz ]

  # Create instance: proc_sys_reset_75MHz, and set properties
  set proc_sys_reset_75MHz [ create_bd_cell -type ip -vlnv xilinx.com:ip:proc_sys_reset:5.0 proc_sys_reset_75MHz ]

  # Create instance: proc_sys_reset_mb, and set properties
  set proc_sys_reset_mb [ create_bd_cell -type ip -vlnv xilinx.com:ip:proc_sys_reset:5.0 proc_sys_reset_mb ]
  set_property -dict [ list \
CONFIG.C_AUX_RESET_HIGH {0} \
 ] $proc_sys_reset_mb

  # Create instance: processing_system7_0, and set properties
  set processing_system7_0 [ create_bd_cell -type ip -vlnv xilinx.com:ip:processing_system7:5.5 processing_system7_0 ]
  set_property -dict [ list \
CONFIG.PCW_ACT_ENET0_PERIPHERAL_FREQMHZ {125.000000} \
CONFIG.PCW_ACT_FPGA1_PERIPHERAL_FREQMHZ {200.000000} \
CONFIG.PCW_ACT_I2C_PERIPHERAL_FREQMHZ {50} \
CONFIG.PCW_ACT_QSPI_PERIPHERAL_FREQMHZ {200.000000} \
CONFIG.PCW_ACT_SDIO_PERIPHERAL_FREQMHZ {100.000000} \
CONFIG.PCW_ACT_UART_PERIPHERAL_FREQMHZ {100.000000} \
CONFIG.PCW_CLK1_FREQ {200000000} \
CONFIG.PCW_DDR_RAM_HIGHADDR {0x3FFFFFFF} \
CONFIG.PCW_ENET0_ENET0_IO {MIO 16 .. 27} \
CONFIG.PCW_ENET0_GRP_MDIO_ENABLE {1} \
CONFIG.PCW_ENET0_GRP_MDIO_IO {MIO 52 .. 53} \
CONFIG.PCW_ENET0_PERIPHERAL_DIVISOR0 {8} \
CONFIG.PCW_ENET0_PERIPHERAL_ENABLE {1} \
CONFIG.PCW_ENET0_RESET_ENABLE {0} \
CONFIG.PCW_ENET0_RESET_IO {<Select>} \
CONFIG.PCW_ENET_RESET_ENABLE {0} \
CONFIG.PCW_ENET_RESET_SELECT {<Select>} \
CONFIG.PCW_EN_CLK1_PORT {1} \
CONFIG.PCW_EN_EMIO_I2C0 {0} \
CONFIG.PCW_EN_EMIO_TTC0 {1} \
CONFIG.PCW_EN_EMIO_TTC1 {1} \
CONFIG.PCW_EN_EMIO_UART1 {0} \
CONFIG.PCW_EN_ENET0 {1} \
CONFIG.PCW_EN_GPIO {1} \
CONFIG.PCW_EN_I2C0 {1} \
CONFIG.PCW_EN_I2C1 {1} \
CONFIG.PCW_EN_QSPI {1} \
CONFIG.PCW_EN_SDIO0 {1} \
CONFIG.PCW_EN_TTC0 {1} \
CONFIG.PCW_EN_TTC1 {1} \
CONFIG.PCW_EN_UART0 {1} \
CONFIG.PCW_EN_UART1 {1} \
CONFIG.PCW_EN_USB0 {1} \
CONFIG.PCW_FCLK0_PERIPHERAL_DIVISOR0 {20} \
CONFIG.PCW_FCLK1_PERIPHERAL_CLKSRC {IO PLL} \
CONFIG.PCW_FCLK1_PERIPHERAL_DIVISOR0 {5} \
CONFIG.PCW_FCLK2_PERIPHERAL_DIVISOR0 {20} \
CONFIG.PCW_FCLK3_PERIPHERAL_DIVISOR0 {20} \
CONFIG.PCW_FCLK_CLK1_BUF {true} \
CONFIG.PCW_FPGA1_PERIPHERAL_FREQMHZ {200} \
CONFIG.PCW_FPGA_FCLK1_ENABLE {1} \
CONFIG.PCW_GPIO_EMIO_GPIO_ENABLE {1} \
CONFIG.PCW_GPIO_MIO_GPIO_ENABLE {1} \
CONFIG.PCW_GPIO_MIO_GPIO_IO {MIO} \
CONFIG.PCW_I2C0_GRP_INT_ENABLE {1} \
CONFIG.PCW_I2C0_GRP_INT_IO {EMIO} \
CONFIG.PCW_I2C0_I2C0_IO {MIO 10 .. 11} \
CONFIG.PCW_I2C0_PERIPHERAL_ENABLE {1} \
CONFIG.PCW_I2C1_GRP_INT_ENABLE {1} \
CONFIG.PCW_I2C1_GRP_INT_IO {EMIO} \
CONFIG.PCW_I2C1_I2C1_IO {EMIO} \
CONFIG.PCW_I2C1_PERIPHERAL_ENABLE {1} \
CONFIG.PCW_I2C_PERIPHERAL_FREQMHZ {111.111115} \
CONFIG.PCW_I2C_RESET_ENABLE {0} \
CONFIG.PCW_I2C_RESET_SELECT {<Select>} \
CONFIG.PCW_IOPLL_CTRL_FBDIV {30} \
CONFIG.PCW_IO_IO_PLL_FREQMHZ {1000.000} \
CONFIG.PCW_IRQ_F2P_INTR {1} \
CONFIG.PCW_MIO_2_PULLUP {disabled} \
CONFIG.PCW_MIO_3_PULLUP {disabled} \
CONFIG.PCW_MIO_40_PULLUP {disabled} \
CONFIG.PCW_MIO_41_PULLUP {disabled} \
CONFIG.PCW_MIO_42_PULLUP {disabled} \
CONFIG.PCW_MIO_43_PULLUP {disabled} \
CONFIG.PCW_MIO_44_PULLUP {disabled} \
CONFIG.PCW_MIO_45_PULLUP {disabled} \
CONFIG.PCW_MIO_46_SLEW {fast} \
CONFIG.PCW_MIO_47_SLEW {fast} \
CONFIG.PCW_MIO_48_SLEW {fast} \
CONFIG.PCW_MIO_49_SLEW {fast} \
CONFIG.PCW_MIO_4_PULLUP {disabled} \
CONFIG.PCW_MIO_5_PULLUP {disabled} \
CONFIG.PCW_MIO_6_PULLUP {disabled} \
CONFIG.PCW_MIO_7_PULLUP {disabled} \
CONFIG.PCW_MIO_8_PULLUP {disabled} \
CONFIG.PCW_M_AXI_GP0_FREQMHZ {50} \
CONFIG.PCW_PACKAGE_NAME {clg484} \
CONFIG.PCW_PCAP_PERIPHERAL_DIVISOR0 {5} \
CONFIG.PCW_PERIPHERAL_BOARD_PRESET {part0} \
CONFIG.PCW_PRESET_BANK1_VOLTAGE {LVCMOS 1.8V} \
CONFIG.PCW_QSPI_GRP_FBCLK_ENABLE {1} \
CONFIG.PCW_QSPI_GRP_FBCLK_IO {MIO 8} \
CONFIG.PCW_QSPI_GRP_SINGLE_SS_ENABLE {1} \
CONFIG.PCW_QSPI_GRP_SINGLE_SS_IO {MIO 1 .. 6} \
CONFIG.PCW_QSPI_PERIPHERAL_DIVISOR0 {5} \
CONFIG.PCW_QSPI_PERIPHERAL_ENABLE {1} \
CONFIG.PCW_QSPI_QSPI_IO {MIO 1 .. 6} \
CONFIG.PCW_SD0_PERIPHERAL_ENABLE {1} \
CONFIG.PCW_SD0_SD0_IO {MIO 40 .. 45} \
CONFIG.PCW_SD1_GRP_CD_ENABLE {1} \
CONFIG.PCW_SD1_GRP_WP_ENABLE {1} \
CONFIG.PCW_SD1_PERIPHERAL_ENABLE {1} \
CONFIG.PCW_SD1_SD1_IO {MIO 46 .. 51} \
CONFIG.PCW_SDIO_PERIPHERAL_DIVISOR0 {10} \
CONFIG.PCW_SDIO_PERIPHERAL_VALID {1} \
CONFIG.PCW_SPI0_PERIPHERAL_ENABLE {1} \
CONFIG.PCW_SPI1_PERIPHERAL_ENABLE {1} \
CONFIG.PCW_TTC0_PERIPHERAL_ENABLE {1} \
CONFIG.PCW_TTC0_TTC0_IO {EMIO} \
CONFIG.PCW_TTC1_PERIPHERAL_ENABLE {1} \
CONFIG.PCW_TTC1_TTC1_IO {EMIO} \
CONFIG.PCW_UART0_PERIPHERAL_ENABLE {1} \
CONFIG.PCW_UART0_UART0_IO {MIO 14 .. 15} \
CONFIG.PCW_UART1_PERIPHERAL_ENABLE {1} \
CONFIG.PCW_UART1_UART1_IO {MIO 12 .. 13} \
CONFIG.PCW_UART_PERIPHERAL_DIVISOR0 {10} \
CONFIG.PCW_UART_PERIPHERAL_VALID {1} \
CONFIG.PCW_UIPARAM_DDR_BOARD_DELAY0 {0.012} \
CONFIG.PCW_UIPARAM_DDR_BOARD_DELAY1 {0.011} \
CONFIG.PCW_UIPARAM_DDR_BOARD_DELAY2 {0.012} \
CONFIG.PCW_UIPARAM_DDR_BOARD_DELAY3 {0.015} \
CONFIG.PCW_UIPARAM_DDR_DEVICE_CAPACITY {4096 MBits} \
CONFIG.PCW_UIPARAM_DDR_DQS_TO_CLK_DELAY_2 {0.001} \
CONFIG.PCW_UIPARAM_DDR_DQS_TO_CLK_DELAY_3 {-0.006} \
CONFIG.PCW_UIPARAM_DDR_DRAM_WIDTH {16 Bits} \
CONFIG.PCW_UIPARAM_DDR_PARTNO {MT41J256M16 RE-125} \
CONFIG.PCW_UIPARAM_DDR_ROW_ADDR_COUNT {15} \
CONFIG.PCW_UIPARAM_DDR_TRAIN_READ_GATE {0} \
CONFIG.PCW_UIPARAM_DDR_T_FAW {40.0} \
CONFIG.PCW_UIPARAM_DDR_T_RC {48.91} \
CONFIG.PCW_UIPARAM_GENERATE_SUMMARY {NONE} \
CONFIG.PCW_USB0_PERIPHERAL_ENABLE {1} \
CONFIG.PCW_USB0_RESET_ENABLE {0} \
CONFIG.PCW_USB0_RESET_IO {<Select>} \
CONFIG.PCW_USB0_USB0_IO {MIO 28 .. 39} \
CONFIG.PCW_USB_RESET_ENABLE {0} \
CONFIG.PCW_USB_RESET_SELECT {<Select>} \
CONFIG.PCW_USE_EXPANDED_IOP {0} \
CONFIG.PCW_USE_FABRIC_INTERRUPT {1} \
CONFIG.PCW_USE_M_AXI_GP0 {1} \
CONFIG.PCW_USE_M_AXI_GP1 {1} \
CONFIG.PCW_USE_S_AXI_GP0 {0} \
CONFIG.PCW_USE_S_AXI_HP0 {1} \
CONFIG.PCW_USE_S_AXI_HP1 {1} \
CONFIG.PCW_USE_S_AXI_HP2 {1} \
 ] $processing_system7_0

  # Create instance: processing_system7_0_axi_periph, and set properties
  set processing_system7_0_axi_periph [ create_bd_cell -type ip -vlnv xilinx.com:ip:axi_interconnect:2.1 processing_system7_0_axi_periph ]
  set_property -dict [ list \
CONFIG.NUM_MI {6} \
 ] $processing_system7_0_axi_periph

  # Create instance: python1300_receiver_color
  create_hier_cell_python1300_receiver_color [current_bd_instance .] python1300_receiver_color

  # Create instance: sobel_filter_htile1_0, and set properties
  set sobel_filter_htile1_0 [ create_bd_cell -type ip -vlnv xilinx.com:hls:sobel_filter_htile1:1.0 sobel_filter_htile1_0 ]

  # Create instance: sobel_filter_htile1_0_if, and set properties
  set sobel_filter_htile1_0_if [ create_bd_cell -type ip -vlnv xilinx.com:ip:axis_accelerator_adapter:2.1 sobel_filter_htile1_0_if ]
  set_property -dict [ list \
CONFIG.C_AP_IARG_0_DIM_1 {1024} \
CONFIG.C_AP_IARG_0_DWIDTH {16} \
CONFIG.C_AP_IARG_0_TYPE {1} \
CONFIG.C_AP_IARG_0_WIDTH {16} \
CONFIG.C_AP_OARG_0_DIM_1 {1024} \
CONFIG.C_AP_OARG_0_DWIDTH {16} \
CONFIG.C_AP_OARG_0_TYPE {1} \
CONFIG.C_AP_OARG_0_WIDTH {16} \
CONFIG.C_INPUT_SCALAR_0_WIDTH {32} \
CONFIG.C_M_AXIS_HAS_TKEEP {1} \
CONFIG.C_M_AXIS_HAS_TSTRB {1} \
CONFIG.C_M_AXIS_TDATA_WIDTH {64} \
CONFIG.C_N_INPUT_ARGS {1} \
CONFIG.C_N_INPUT_SCALARS {1} \
CONFIG.C_N_OUTPUT_ARGS {1} \
CONFIG.C_S_AXIS_TDATA_WIDTH {64} \
 ] $sobel_filter_htile1_0_if

  # Create instance: util_vector_logic_1, and set properties
  set util_vector_logic_1 [ create_bd_cell -type ip -vlnv xilinx.com:ip:util_vector_logic:2.0 util_vector_logic_1 ]
  set_property -dict [ list \
CONFIG.C_SIZE {1} \
 ] $util_vector_logic_1

  # Create instance: xlconcat_0, and set properties
  set xlconcat_0 [ create_bd_cell -type ip -vlnv xilinx.com:ip:xlconcat:2.1 xlconcat_0 ]
  set_property -dict [ list \
CONFIG.NUM_PORTS {2} \
 ] $xlconcat_0

  # Create instance: xlconstant_0, and set properties
  set xlconstant_0 [ create_bd_cell -type ip -vlnv xilinx.com:ip:xlconstant:1.1 xlconstant_0 ]
  set_property -dict [ list \
CONFIG.CONST_VAL {0} \
CONFIG.CONST_WIDTH {4} \
 ] $xlconstant_0

  # Create instance: xlconstant_1, and set properties
  set xlconstant_1 [ create_bd_cell -type ip -vlnv xilinx.com:ip:xlconstant:1.1 xlconstant_1 ]
  set_property -dict [ list \
CONFIG.CONST_VAL {0} \
CONFIG.CONST_WIDTH {8} \
 ] $xlconstant_1

  # Create instance: xlslice_0, and set properties
  set xlslice_0 [ create_bd_cell -type ip -vlnv xilinx.com:ip:xlslice:1.0 xlslice_0 ]
  set_property -dict [ list \
CONFIG.DIN_FROM {0} \
CONFIG.DIN_TO {0} \
CONFIG.DIN_WIDTH {64} \
 ] $xlslice_0

  # Create interface connections
  connect_bd_intf_net -intf_net IO_CAM_IN_1 [get_bd_intf_ports IO_PYTHON_CAM] [get_bd_intf_pins python1300_receiver_color/IO_CAM_IN]
  connect_bd_intf_net -intf_net axi_ic_processing_system7_0_M_AXI_GP1_M00_AXI [get_bd_intf_pins axi_ic_processing_system7_0_M_AXI_GP1/M00_AXI] [get_bd_intf_pins sobel_filter_htile1_0_if/S_AXI]
  connect_bd_intf_net -intf_net axi_ic_processing_system7_0_M_AXI_GP1_M01_AXI [get_bd_intf_pins axi_ic_processing_system7_0_M_AXI_GP1/M01_AXI] [get_bd_intf_pins dm_0/S_AXI_LITE]
  connect_bd_intf_net -intf_net axi_ic_processing_system7_0_M_AXI_GP1_M02_AXI [get_bd_intf_pins axi_ic_processing_system7_0_M_AXI_GP1/M02_AXI] [get_bd_intf_pins dm_1/S_AXI_LITE]
  connect_bd_intf_net -intf_net axi_ic_processing_system7_0_S_AXI_HP2_M00_AXI [get_bd_intf_pins axi_ic_processing_system7_0_S_AXI_HP2/M00_AXI] [get_bd_intf_pins processing_system7_0/S_AXI_HP2]
  connect_bd_intf_net -intf_net axi_iic_0_IIC [get_bd_intf_ports fmc_imageon_iic] [get_bd_intf_pins fmc2_imageon_iic/IIC]
  connect_bd_intf_net -intf_net axi_mem_intercon_1_M00_AXI [get_bd_intf_pins axi_mem_intercon_1/M00_AXI] [get_bd_intf_pins processing_system7_0/S_AXI_HP1]
  connect_bd_intf_net -intf_net axi_mem_intercon_M00_AXI [get_bd_intf_pins axi_mem_intercon/M00_AXI] [get_bd_intf_pins processing_system7_0/S_AXI_HP0]
  connect_bd_intf_net -intf_net axi_vdma_0_M_AXIS_MM2S [get_bd_intf_pins axi_vdma_0/M_AXIS_MM2S] [get_bd_intf_pins imageon_hdmi_out/AXIS_vid_in]
  connect_bd_intf_net -intf_net axi_vdma_0_M_AXI_MM2S [get_bd_intf_pins axi_mem_intercon/S00_AXI] [get_bd_intf_pins axi_vdma_0/M_AXI_MM2S]
  connect_bd_intf_net -intf_net axi_vdma_0_M_AXI_S2MM [get_bd_intf_pins axi_mem_intercon/S01_AXI] [get_bd_intf_pins axi_vdma_0/M_AXI_S2MM]
  connect_bd_intf_net -intf_net dm_0_M_AXIS_MM2S [get_bd_intf_pins dm_0/M_AXIS_MM2S] [get_bd_intf_pins sobel_filter_htile1_0_if/S_AXIS_0]
  connect_bd_intf_net -intf_net dm_0_M_AXI_MM2S [get_bd_intf_pins axi_ic_processing_system7_0_S_AXI_HP2/S00_AXI] [get_bd_intf_pins dm_0/M_AXI_MM2S]
  connect_bd_intf_net -intf_net dm_1_M_AXI_S2MM [get_bd_intf_pins axi_ic_processing_system7_0_S_AXI_HP2/S01_AXI] [get_bd_intf_pins dm_1/M_AXI_S2MM]
  connect_bd_intf_net -intf_net imageon_hdmi_out_HDMI_vid_out [get_bd_intf_ports fmc_hdmio_io] [get_bd_intf_pins imageon_hdmi_out/HDMI_vid_out]
  connect_bd_intf_net -intf_net microblaze_0_M_AXI_DC [get_bd_intf_pins axi_mem_intercon_1/S00_AXI] [get_bd_intf_pins microblaze_0/M_AXI_DC]
  connect_bd_intf_net -intf_net microblaze_0_M_AXI_IC [get_bd_intf_pins axi_mem_intercon_1/S01_AXI] [get_bd_intf_pins microblaze_0/M_AXI_IC]
  connect_bd_intf_net -intf_net microblaze_0_axi_dp [get_bd_intf_pins microblaze_0/M_AXI_DP] [get_bd_intf_pins microblaze_0_axi_periph/S00_AXI]
  connect_bd_intf_net -intf_net microblaze_0_axi_periph_M01_AXI [get_bd_intf_pins axi_uartlite_0/S_AXI] [get_bd_intf_pins microblaze_0_axi_periph/M01_AXI]
  connect_bd_intf_net -intf_net microblaze_0_axi_periph_M02_AXI [get_bd_intf_pins microblaze_0_axi_periph/M02_AXI] [get_bd_intf_pins mutex_0/S1_AXI]
  connect_bd_intf_net -intf_net microblaze_0_axi_periph_M03_AXI [get_bd_intf_pins bce_fp12_1x8_0_axiw_0/s_axi] [get_bd_intf_pins microblaze_0_axi_periph/M03_AXI]
  connect_bd_intf_net -intf_net microblaze_0_axi_periph_M04_AXI [get_bd_intf_pins axi_timer_0/S_AXI] [get_bd_intf_pins microblaze_0_axi_periph/M04_AXI]
  connect_bd_intf_net -intf_net microblaze_0_debug [get_bd_intf_pins mdm_1/MBDEBUG_0] [get_bd_intf_pins microblaze_0/DEBUG]
  connect_bd_intf_net -intf_net microblaze_0_intc_axi [get_bd_intf_pins microblaze_0_axi_intc/s_axi] [get_bd_intf_pins microblaze_0_axi_periph/M00_AXI]
  connect_bd_intf_net -intf_net microblaze_0_interrupt [get_bd_intf_pins microblaze_0/INTERRUPT] [get_bd_intf_pins microblaze_0_axi_intc/interrupt]
  connect_bd_intf_net -intf_net onsemi_python_spi_0_IO_SPI_OUT [get_bd_intf_ports IO_PYTHON_SPI] [get_bd_intf_pins onsemi_python_spi_0/IO_SPI_OUT]
  connect_bd_intf_net -intf_net processing_system7_0_DDR [get_bd_intf_ports DDR] [get_bd_intf_pins processing_system7_0/DDR]
  connect_bd_intf_net -intf_net processing_system7_0_FIXED_IO [get_bd_intf_ports FIXED_IO] [get_bd_intf_pins processing_system7_0/FIXED_IO]
  connect_bd_intf_net -intf_net processing_system7_0_M_AXI_GP0 [get_bd_intf_pins processing_system7_0/M_AXI_GP0] [get_bd_intf_pins processing_system7_0_axi_periph/S00_AXI]
  connect_bd_intf_net -intf_net processing_system7_0_M_AXI_GP1 [get_bd_intf_pins axi_ic_processing_system7_0_M_AXI_GP1/S00_AXI] [get_bd_intf_pins processing_system7_0/M_AXI_GP1]
  connect_bd_intf_net -intf_net processing_system7_0_axi_periph_M00_AXI [get_bd_intf_pins fmc2_imageon_iic/S_AXI] [get_bd_intf_pins processing_system7_0_axi_periph/M00_AXI]
  connect_bd_intf_net -intf_net processing_system7_0_axi_periph_M01_AXI [get_bd_intf_pins imageon_hdmi_out/AXI_lite] [get_bd_intf_pins processing_system7_0_axi_periph/M01_AXI]
  connect_bd_intf_net -intf_net processing_system7_0_axi_periph_M02_AXI [get_bd_intf_pins axi_vdma_0/S_AXI_LITE] [get_bd_intf_pins processing_system7_0_axi_periph/M02_AXI]
  connect_bd_intf_net -intf_net processing_system7_0_axi_periph_M03_AXI [get_bd_intf_pins mutex_0/S0_AXI] [get_bd_intf_pins processing_system7_0_axi_periph/M03_AXI]
  connect_bd_intf_net -intf_net processing_system7_0_axi_periph_M04_AXI [get_bd_intf_pins processing_system7_0_axi_periph/M04_AXI] [get_bd_intf_pins python1300_receiver_color/S00_AXI]
  connect_bd_intf_net -intf_net processing_system7_0_axi_periph_M05_AXI [get_bd_intf_pins onsemi_python_spi_0/S00_AXI] [get_bd_intf_pins processing_system7_0_axi_periph/M05_AXI]
  connect_bd_intf_net -intf_net sobel_filter_htile1_0_if_AP_CTRL [get_bd_intf_pins sobel_filter_htile1_0/ap_ctrl] [get_bd_intf_pins sobel_filter_htile1_0_if/AP_CTRL]
  connect_bd_intf_net -intf_net sobel_filter_htile1_0_if_M_AXIS_0 [get_bd_intf_pins dm_1/S_AXIS_S2MM] [get_bd_intf_pins sobel_filter_htile1_0_if/M_AXIS_0]
  connect_bd_intf_net -intf_net sobel_filter_htile1_0_in_pix [get_bd_intf_pins sobel_filter_htile1_0/in_pix] [get_bd_intf_pins sobel_filter_htile1_0_if/AP_FIFO_IARG_0]
  connect_bd_intf_net -intf_net sobel_filter_htile1_0_output_edge [get_bd_intf_pins sobel_filter_htile1_0/output_edge] [get_bd_intf_pins sobel_filter_htile1_0_if/AP_FIFO_OARG_0]
  connect_bd_intf_net -intf_net v_cresample_0_video_out [get_bd_intf_pins axi_vdma_0/S_AXIS_S2MM] [get_bd_intf_pins python1300_receiver_color/video_out]

  # Create port connections
  connect_bd_net -net axi_iic_0_gpo [get_bd_ports fmc_imageon_iic_rst_n] [get_bd_pins fmc2_imageon_iic/gpo]
  connect_bd_net -net axi_timer_0_interrupt [get_bd_pins axi_timer_0/interrupt] [get_bd_pins microblaze_0_xlconcat/In1]
  connect_bd_net -net axi_uartlite_0_interrupt [get_bd_pins axi_uartlite_0/interrupt] [get_bd_pins microblaze_0_xlconcat/In0]
  connect_bd_net -net axi_uartlite_0_tx [get_bd_ports uart_pmod_rx] [get_bd_pins axi_uartlite_0/tx]
  connect_bd_net -net axis_resetn_1 [get_bd_pins axi_mem_intercon/M00_ARESETN] [get_bd_pins axi_mem_intercon/S00_ARESETN] [get_bd_pins axi_mem_intercon/S01_ARESETN] [get_bd_pins dm_0/axi_resetn] [get_bd_pins dm_1/axi_resetn] [get_bd_pins imageon_hdmi_out/axis_resetn] [get_bd_pins proc_sys_reset_150MHz/peripheral_aresetn] [get_bd_pins python1300_receiver_color/aresetn] [get_bd_pins sobel_filter_htile1_0_if/m_axis_aresetn] [get_bd_pins sobel_filter_htile1_0_if/s_axi_aresetn] [get_bd_pins sobel_filter_htile1_0_if/s_axis_aresetn]
  connect_bd_net -net bce_fp12_1x8_0_axiw_0_mem_bce_dfroma1 [get_bd_pins bce_fp12_1x8_0_axiw_0/mem_bce_dfroma1] [get_bd_pins bce_fp12_1x8_0_dsp_0/mem_bce_dfroma1]
  connect_bd_net -net bce_fp12_1x8_0_axiw_0_mem_bce_dfroma2 [get_bd_pins bce_fp12_1x8_0_axiw_0/mem_bce_dfroma2] [get_bd_pins bce_fp12_1x8_0_dsp_0/mem_bce_dfroma2]
  connect_bd_net -net bce_fp12_1x8_0_axiw_0_mem_bce_dfroma3 [get_bd_pins bce_fp12_1x8_0_axiw_0/mem_bce_dfroma3] [get_bd_pins bce_fp12_1x8_0_dsp_0/mem_bce_dfroma3]
  connect_bd_net -net bce_fp12_1x8_0_axiw_0_mem_bce_dfroma4 [get_bd_pins bce_fp12_1x8_0_axiw_0/mem_bce_dfroma4] [get_bd_pins bce_fp12_1x8_0_dsp_0/mem_bce_dfroma4]
  connect_bd_net -net bce_fp12_1x8_0_axiw_0_mem_bce_dfroma5 [get_bd_pins bce_fp12_1x8_0_axiw_0/mem_bce_dfroma5] [get_bd_pins bce_fp12_1x8_0_dsp_0/mem_bce_dfroma5]
  connect_bd_net -net bce_fp12_1x8_0_axiw_0_mem_bce_dfroma6 [get_bd_pins bce_fp12_1x8_0_axiw_0/mem_bce_dfroma6] [get_bd_pins bce_fp12_1x8_0_dsp_0/mem_bce_dfroma6]
  connect_bd_net -net bce_fp12_1x8_0_axiw_0_mem_bce_dfroma7 [get_bd_pins bce_fp12_1x8_0_axiw_0/mem_bce_dfroma7] [get_bd_pins bce_fp12_1x8_0_dsp_0/mem_bce_dfroma7]
  connect_bd_net -net bce_fp12_1x8_0_axiw_0_mem_bce_dfroma8 [get_bd_pins bce_fp12_1x8_0_axiw_0/mem_bce_dfroma8] [get_bd_pins bce_fp12_1x8_0_dsp_0/mem_bce_dfroma8]
  connect_bd_net -net bce_fp12_1x8_0_axiw_0_mem_bce_dfromb1 [get_bd_pins bce_fp12_1x8_0_axiw_0/mem_bce_dfromb1] [get_bd_pins bce_fp12_1x8_0_dsp_0/mem_bce_dfromb1]
  connect_bd_net -net bce_fp12_1x8_0_axiw_0_mem_bce_dfromb2 [get_bd_pins bce_fp12_1x8_0_axiw_0/mem_bce_dfromb2] [get_bd_pins bce_fp12_1x8_0_dsp_0/mem_bce_dfromb2]
  connect_bd_net -net bce_fp12_1x8_0_axiw_0_mem_bce_dfromb3 [get_bd_pins bce_fp12_1x8_0_axiw_0/mem_bce_dfromb3] [get_bd_pins bce_fp12_1x8_0_dsp_0/mem_bce_dfromb3]
  connect_bd_net -net bce_fp12_1x8_0_axiw_0_mem_bce_dfromb4 [get_bd_pins bce_fp12_1x8_0_axiw_0/mem_bce_dfromb4] [get_bd_pins bce_fp12_1x8_0_dsp_0/mem_bce_dfromb4]
  connect_bd_net -net bce_fp12_1x8_0_axiw_0_mem_bce_dfromb5 [get_bd_pins bce_fp12_1x8_0_axiw_0/mem_bce_dfromb5] [get_bd_pins bce_fp12_1x8_0_dsp_0/mem_bce_dfromb5]
  connect_bd_net -net bce_fp12_1x8_0_axiw_0_mem_bce_dfromb6 [get_bd_pins bce_fp12_1x8_0_axiw_0/mem_bce_dfromb6] [get_bd_pins bce_fp12_1x8_0_dsp_0/mem_bce_dfromb6]
  connect_bd_net -net bce_fp12_1x8_0_axiw_0_mem_bce_dfromb7 [get_bd_pins bce_fp12_1x8_0_axiw_0/mem_bce_dfromb7] [get_bd_pins bce_fp12_1x8_0_dsp_0/mem_bce_dfromb7]
  connect_bd_net -net bce_fp12_1x8_0_axiw_0_mem_bce_dfromb8 [get_bd_pins bce_fp12_1x8_0_axiw_0/mem_bce_dfromb8] [get_bd_pins bce_fp12_1x8_0_dsp_0/mem_bce_dfromb8]
  connect_bd_net -net bce_fp12_1x8_0_axiw_0_mem_bce_dfromz1 [get_bd_pins bce_fp12_1x8_0_axiw_0/mem_bce_dfromz1] [get_bd_pins bce_fp12_1x8_0_dsp_0/mem_bce_dfromz1]
  connect_bd_net -net bce_fp12_1x8_0_axiw_0_mem_bce_dfromz2 [get_bd_pins bce_fp12_1x8_0_axiw_0/mem_bce_dfromz2] [get_bd_pins bce_fp12_1x8_0_dsp_0/mem_bce_dfromz2]
  connect_bd_net -net bce_fp12_1x8_0_axiw_0_mem_bce_dfromz3 [get_bd_pins bce_fp12_1x8_0_axiw_0/mem_bce_dfromz3] [get_bd_pins bce_fp12_1x8_0_dsp_0/mem_bce_dfromz3]
  connect_bd_net -net bce_fp12_1x8_0_axiw_0_mem_bce_dfromz4 [get_bd_pins bce_fp12_1x8_0_axiw_0/mem_bce_dfromz4] [get_bd_pins bce_fp12_1x8_0_dsp_0/mem_bce_dfromz4]
  connect_bd_net -net bce_fp12_1x8_0_axiw_0_mem_bce_dfromz5 [get_bd_pins bce_fp12_1x8_0_axiw_0/mem_bce_dfromz5] [get_bd_pins bce_fp12_1x8_0_dsp_0/mem_bce_dfromz5]
  connect_bd_net -net bce_fp12_1x8_0_axiw_0_mem_bce_dfromz6 [get_bd_pins bce_fp12_1x8_0_axiw_0/mem_bce_dfromz6] [get_bd_pins bce_fp12_1x8_0_dsp_0/mem_bce_dfromz6]
  connect_bd_net -net bce_fp12_1x8_0_axiw_0_mem_bce_dfromz7 [get_bd_pins bce_fp12_1x8_0_axiw_0/mem_bce_dfromz7] [get_bd_pins bce_fp12_1x8_0_dsp_0/mem_bce_dfromz7]
  connect_bd_net -net bce_fp12_1x8_0_axiw_0_mem_bce_dfromz8 [get_bd_pins bce_fp12_1x8_0_axiw_0/mem_bce_dfromz8] [get_bd_pins bce_fp12_1x8_0_dsp_0/mem_bce_dfromz8]
  connect_bd_net -net bce_fp12_1x8_0_axiw_0_mem_bce_i_hi [get_bd_pins bce_fp12_1x8_0_axiw_0/mem_bce_i_hi] [get_bd_pins bce_fp12_1x8_0_dsp_0/mem_bce_i_hi]
  connect_bd_net -net bce_fp12_1x8_0_axiw_0_mem_bce_i_lo [get_bd_pins bce_fp12_1x8_0_axiw_0/mem_bce_i_lo] [get_bd_pins bce_fp12_1x8_0_dsp_0/mem_bce_i_lo]
  connect_bd_net -net bce_fp12_1x8_0_axiw_0_mem_bce_op [get_bd_pins bce_fp12_1x8_0_axiw_0/mem_bce_op] [get_bd_pins bce_fp12_1x8_0_dsp_0/mem_bce_op]
  connect_bd_net -net bce_fp12_1x8_0_axiw_0_mem_bce_we [get_bd_pins bce_fp12_1x8_0_axiw_0/mem_bce_we] [get_bd_pins bce_fp12_1x8_0_dsp_0/mem_bce_we]
  connect_bd_net -net bce_fp12_1x8_0_dsp_0_mem_bce_atoa [get_bd_pins bce_fp12_1x8_0_axiw_0/mem_bce_atoa] [get_bd_pins bce_fp12_1x8_0_dsp_0/mem_bce_atoa]
  connect_bd_net -net bce_fp12_1x8_0_dsp_0_mem_bce_atob [get_bd_pins bce_fp12_1x8_0_axiw_0/mem_bce_atob] [get_bd_pins bce_fp12_1x8_0_dsp_0/mem_bce_atob]
  connect_bd_net -net bce_fp12_1x8_0_dsp_0_mem_bce_atoz [get_bd_pins bce_fp12_1x8_0_axiw_0/mem_bce_atoz] [get_bd_pins bce_fp12_1x8_0_dsp_0/mem_bce_atoz]
  connect_bd_net -net bce_fp12_1x8_0_dsp_0_mem_bce_done [get_bd_pins bce_fp12_1x8_0_axiw_0/mem_bce_done] [get_bd_pins bce_fp12_1x8_0_dsp_0/mem_bce_done]
  connect_bd_net -net bce_fp12_1x8_0_dsp_0_mem_bce_dtoa1 [get_bd_pins bce_fp12_1x8_0_axiw_0/mem_bce_dtoa1] [get_bd_pins bce_fp12_1x8_0_dsp_0/mem_bce_dtoa1]
  connect_bd_net -net bce_fp12_1x8_0_dsp_0_mem_bce_dtoa2 [get_bd_pins bce_fp12_1x8_0_axiw_0/mem_bce_dtoa2] [get_bd_pins bce_fp12_1x8_0_dsp_0/mem_bce_dtoa2]
  connect_bd_net -net bce_fp12_1x8_0_dsp_0_mem_bce_dtoa3 [get_bd_pins bce_fp12_1x8_0_axiw_0/mem_bce_dtoa3] [get_bd_pins bce_fp12_1x8_0_dsp_0/mem_bce_dtoa3]
  connect_bd_net -net bce_fp12_1x8_0_dsp_0_mem_bce_dtoa4 [get_bd_pins bce_fp12_1x8_0_axiw_0/mem_bce_dtoa4] [get_bd_pins bce_fp12_1x8_0_dsp_0/mem_bce_dtoa4]
  connect_bd_net -net bce_fp12_1x8_0_dsp_0_mem_bce_dtoa5 [get_bd_pins bce_fp12_1x8_0_axiw_0/mem_bce_dtoa5] [get_bd_pins bce_fp12_1x8_0_dsp_0/mem_bce_dtoa5]
  connect_bd_net -net bce_fp12_1x8_0_dsp_0_mem_bce_dtoa6 [get_bd_pins bce_fp12_1x8_0_axiw_0/mem_bce_dtoa6] [get_bd_pins bce_fp12_1x8_0_dsp_0/mem_bce_dtoa6]
  connect_bd_net -net bce_fp12_1x8_0_dsp_0_mem_bce_dtoa7 [get_bd_pins bce_fp12_1x8_0_axiw_0/mem_bce_dtoa7] [get_bd_pins bce_fp12_1x8_0_dsp_0/mem_bce_dtoa7]
  connect_bd_net -net bce_fp12_1x8_0_dsp_0_mem_bce_dtoa8 [get_bd_pins bce_fp12_1x8_0_axiw_0/mem_bce_dtoa8] [get_bd_pins bce_fp12_1x8_0_dsp_0/mem_bce_dtoa8]
  connect_bd_net -net bce_fp12_1x8_0_dsp_0_mem_bce_dtob1 [get_bd_pins bce_fp12_1x8_0_axiw_0/mem_bce_dtob1] [get_bd_pins bce_fp12_1x8_0_dsp_0/mem_bce_dtob1]
  connect_bd_net -net bce_fp12_1x8_0_dsp_0_mem_bce_dtob2 [get_bd_pins bce_fp12_1x8_0_axiw_0/mem_bce_dtob2] [get_bd_pins bce_fp12_1x8_0_dsp_0/mem_bce_dtob2]
  connect_bd_net -net bce_fp12_1x8_0_dsp_0_mem_bce_dtob3 [get_bd_pins bce_fp12_1x8_0_axiw_0/mem_bce_dtob3] [get_bd_pins bce_fp12_1x8_0_dsp_0/mem_bce_dtob3]
  connect_bd_net -net bce_fp12_1x8_0_dsp_0_mem_bce_dtob4 [get_bd_pins bce_fp12_1x8_0_axiw_0/mem_bce_dtob4] [get_bd_pins bce_fp12_1x8_0_dsp_0/mem_bce_dtob4]
  connect_bd_net -net bce_fp12_1x8_0_dsp_0_mem_bce_dtob5 [get_bd_pins bce_fp12_1x8_0_axiw_0/mem_bce_dtob5] [get_bd_pins bce_fp12_1x8_0_dsp_0/mem_bce_dtob5]
  connect_bd_net -net bce_fp12_1x8_0_dsp_0_mem_bce_dtob6 [get_bd_pins bce_fp12_1x8_0_axiw_0/mem_bce_dtob6] [get_bd_pins bce_fp12_1x8_0_dsp_0/mem_bce_dtob6]
  connect_bd_net -net bce_fp12_1x8_0_dsp_0_mem_bce_dtob7 [get_bd_pins bce_fp12_1x8_0_axiw_0/mem_bce_dtob7] [get_bd_pins bce_fp12_1x8_0_dsp_0/mem_bce_dtob7]
  connect_bd_net -net bce_fp12_1x8_0_dsp_0_mem_bce_dtob8 [get_bd_pins bce_fp12_1x8_0_axiw_0/mem_bce_dtob8] [get_bd_pins bce_fp12_1x8_0_dsp_0/mem_bce_dtob8]
  connect_bd_net -net bce_fp12_1x8_0_dsp_0_mem_bce_dtoz1 [get_bd_pins bce_fp12_1x8_0_axiw_0/mem_bce_dtoz1] [get_bd_pins bce_fp12_1x8_0_dsp_0/mem_bce_dtoz1]
  connect_bd_net -net bce_fp12_1x8_0_dsp_0_mem_bce_dtoz2 [get_bd_pins bce_fp12_1x8_0_axiw_0/mem_bce_dtoz2] [get_bd_pins bce_fp12_1x8_0_dsp_0/mem_bce_dtoz2]
  connect_bd_net -net bce_fp12_1x8_0_dsp_0_mem_bce_dtoz3 [get_bd_pins bce_fp12_1x8_0_axiw_0/mem_bce_dtoz3] [get_bd_pins bce_fp12_1x8_0_dsp_0/mem_bce_dtoz3]
  connect_bd_net -net bce_fp12_1x8_0_dsp_0_mem_bce_dtoz4 [get_bd_pins bce_fp12_1x8_0_axiw_0/mem_bce_dtoz4] [get_bd_pins bce_fp12_1x8_0_dsp_0/mem_bce_dtoz4]
  connect_bd_net -net bce_fp12_1x8_0_dsp_0_mem_bce_dtoz5 [get_bd_pins bce_fp12_1x8_0_axiw_0/mem_bce_dtoz5] [get_bd_pins bce_fp12_1x8_0_dsp_0/mem_bce_dtoz5]
  connect_bd_net -net bce_fp12_1x8_0_dsp_0_mem_bce_dtoz6 [get_bd_pins bce_fp12_1x8_0_axiw_0/mem_bce_dtoz6] [get_bd_pins bce_fp12_1x8_0_dsp_0/mem_bce_dtoz6]
  connect_bd_net -net bce_fp12_1x8_0_dsp_0_mem_bce_dtoz7 [get_bd_pins bce_fp12_1x8_0_axiw_0/mem_bce_dtoz7] [get_bd_pins bce_fp12_1x8_0_dsp_0/mem_bce_dtoz7]
  connect_bd_net -net bce_fp12_1x8_0_dsp_0_mem_bce_dtoz8 [get_bd_pins bce_fp12_1x8_0_axiw_0/mem_bce_dtoz8] [get_bd_pins bce_fp12_1x8_0_dsp_0/mem_bce_dtoz8]
  connect_bd_net -net bce_fp12_1x8_0_dsp_0_mem_bce_wea [get_bd_pins bce_fp12_1x8_0_axiw_0/mem_bce_wea] [get_bd_pins bce_fp12_1x8_0_dsp_0/mem_bce_wea]
  connect_bd_net -net bce_fp12_1x8_0_dsp_0_mem_bce_web [get_bd_pins bce_fp12_1x8_0_axiw_0/mem_bce_web] [get_bd_pins bce_fp12_1x8_0_dsp_0/mem_bce_web]
  connect_bd_net -net bce_fp12_1x8_0_dsp_0_mem_bce_wez [get_bd_pins bce_fp12_1x8_0_axiw_0/mem_bce_wez] [get_bd_pins bce_fp12_1x8_0_dsp_0/mem_bce_wez]
  connect_bd_net -net clk_wiz_148_5_clk_out1 [get_bd_pins clk_wiz_108MHz/clk_out1] [get_bd_pins imageon_hdmi_out/vid_out_clk] [get_bd_pins proc_sys_reset_108MHz/slowest_sync_clk] [get_bd_pins python1300_receiver_color/clk]
  connect_bd_net -net clk_wiz_148_5_locked [get_bd_pins clk_wiz_108MHz/locked] [get_bd_pins util_vector_logic_1/Op2]
  connect_bd_net -net clk_wiz_1_clk_out1 [get_bd_pins axi_ic_processing_system7_0_M_AXI_GP1/ACLK] [get_bd_pins axi_ic_processing_system7_0_M_AXI_GP1/M00_ACLK] [get_bd_pins axi_ic_processing_system7_0_M_AXI_GP1/M01_ACLK] [get_bd_pins axi_ic_processing_system7_0_M_AXI_GP1/M02_ACLK] [get_bd_pins axi_ic_processing_system7_0_M_AXI_GP1/S00_ACLK] [get_bd_pins axi_ic_processing_system7_0_S_AXI_HP2/ACLK] [get_bd_pins axi_ic_processing_system7_0_S_AXI_HP2/M00_ACLK] [get_bd_pins axi_ic_processing_system7_0_S_AXI_HP2/S00_ACLK] [get_bd_pins axi_ic_processing_system7_0_S_AXI_HP2/S01_ACLK] [get_bd_pins axi_mem_intercon/ACLK] [get_bd_pins axi_mem_intercon/M00_ACLK] [get_bd_pins axi_mem_intercon/S00_ACLK] [get_bd_pins axi_mem_intercon/S01_ACLK] [get_bd_pins axi_vdma_0/m_axi_mm2s_aclk] [get_bd_pins axi_vdma_0/m_axi_s2mm_aclk] [get_bd_pins axi_vdma_0/m_axis_mm2s_aclk] [get_bd_pins axi_vdma_0/s_axis_s2mm_aclk] [get_bd_pins clk_wiz_1/clk_out1] [get_bd_pins dm_0/m_axi_mm2s_aclk] [get_bd_pins dm_0/s_axi_lite_aclk] [get_bd_pins dm_1/m_axi_s2mm_aclk] [get_bd_pins dm_1/s_axi_lite_aclk] [get_bd_pins imageon_hdmi_out/axis_clk] [get_bd_pins proc_sys_reset_150MHz/slowest_sync_clk] [get_bd_pins processing_system7_0/M_AXI_GP1_ACLK] [get_bd_pins processing_system7_0/S_AXI_HP0_ACLK] [get_bd_pins processing_system7_0/S_AXI_HP2_ACLK] [get_bd_pins python1300_receiver_color/aclk] [get_bd_pins sobel_filter_htile1_0/ap_clk] [get_bd_pins sobel_filter_htile1_0_if/aclk] [get_bd_pins sobel_filter_htile1_0_if/m_axis_aclk] [get_bd_pins sobel_filter_htile1_0_if/s_axi_aclk] [get_bd_pins sobel_filter_htile1_0_if/s_axis_aclk]
  connect_bd_net -net clk_wiz_1_clk_out2 [get_bd_pins bce_fp12_1x8_0_axiw_0/sysgen_clk] [get_bd_pins bce_fp12_1x8_0_dsp_0/clk] [get_bd_pins clk_wiz_1/clk_out2] [get_bd_pins proc_sys_reset_120MHz/slowest_sync_clk]
  connect_bd_net -net clk_wiz_1_clk_out4 [get_bd_pins clk_wiz_1/clk_out4] [get_bd_pins proc_sys_reset_75MHz/slowest_sync_clk]
  connect_bd_net -net clk_wiz_1_locked [get_bd_pins proc_sys_reset_100MHz/dcm_locked] [get_bd_pins proc_sys_reset_108MHz/dcm_locked] [get_bd_pins proc_sys_reset_120MHz/dcm_locked] [get_bd_pins proc_sys_reset_150MHz/dcm_locked] [get_bd_pins proc_sys_reset_75MHz/dcm_locked] [get_bd_pins util_vector_logic_1/Res]
  connect_bd_net -net clk_wiz_1_locked1 [get_bd_pins clk_wiz_1/locked] [get_bd_pins util_vector_logic_1/Op1]
  connect_bd_net -net dm_0_mm2s_introut [get_bd_pins dm_0/mm2s_introut] [get_bd_pins xlconcat_0/In0]
  connect_bd_net -net dm_1_s2mm_introut [get_bd_pins dm_1/s2mm_introut] [get_bd_pins xlconcat_0/In1]
  connect_bd_net -net mdm_1_debug_sys_rst [get_bd_pins mdm_1/Debug_SYS_Rst] [get_bd_pins proc_sys_reset_100MHz/mb_debug_sys_rst]
  connect_bd_net -net microblaze_0_Clk [get_bd_pins axi_mem_intercon_1/ACLK] [get_bd_pins axi_mem_intercon_1/M00_ACLK] [get_bd_pins axi_mem_intercon_1/S00_ACLK] [get_bd_pins axi_mem_intercon_1/S01_ACLK] [get_bd_pins axi_timer_0/s_axi_aclk] [get_bd_pins axi_uartlite_0/s_axi_aclk] [get_bd_pins bce_fp12_1x8_0_axiw_0/axi_aclk] [get_bd_pins clk_wiz_1/clk_out3] [get_bd_pins microblaze_0/Clk] [get_bd_pins microblaze_0_axi_intc/processor_clk] [get_bd_pins microblaze_0_axi_intc/s_axi_aclk] [get_bd_pins microblaze_0_axi_periph/ACLK] [get_bd_pins microblaze_0_axi_periph/M00_ACLK] [get_bd_pins microblaze_0_axi_periph/M01_ACLK] [get_bd_pins microblaze_0_axi_periph/M02_ACLK] [get_bd_pins microblaze_0_axi_periph/M03_ACLK] [get_bd_pins microblaze_0_axi_periph/M04_ACLK] [get_bd_pins microblaze_0_axi_periph/S00_ACLK] [get_bd_pins mutex_0/S1_AXI_ACLK] [get_bd_pins proc_sys_reset_100MHz/slowest_sync_clk] [get_bd_pins proc_sys_reset_mb/slowest_sync_clk] [get_bd_pins processing_system7_0/S_AXI_HP1_ACLK]
  connect_bd_net -net microblaze_0_intr [get_bd_pins microblaze_0_axi_intc/intr] [get_bd_pins microblaze_0_xlconcat/dout]
  connect_bd_net -net proc_sys_reset_100MHz_interconnect_aresetn [get_bd_pins axi_mem_intercon_1/ARESETN] [get_bd_pins microblaze_0_axi_periph/ARESETN] [get_bd_pins proc_sys_reset_100MHz/interconnect_aresetn]
  connect_bd_net -net proc_sys_reset_100MHz_peripheral_aresetn [get_bd_pins axi_mem_intercon_1/M00_ARESETN] [get_bd_pins axi_mem_intercon_1/S00_ARESETN] [get_bd_pins axi_mem_intercon_1/S01_ARESETN] [get_bd_pins axi_timer_0/s_axi_aresetn] [get_bd_pins axi_uartlite_0/s_axi_aresetn] [get_bd_pins bce_fp12_1x8_0_axiw_0/axi_aresetn] [get_bd_pins microblaze_0_axi_intc/s_axi_aresetn] [get_bd_pins microblaze_0_axi_periph/M00_ARESETN] [get_bd_pins microblaze_0_axi_periph/M01_ARESETN] [get_bd_pins microblaze_0_axi_periph/M02_ARESETN] [get_bd_pins microblaze_0_axi_periph/M03_ARESETN] [get_bd_pins microblaze_0_axi_periph/M04_ARESETN] [get_bd_pins microblaze_0_axi_periph/S00_ARESETN] [get_bd_pins mutex_0/S1_AXI_ARESETN] [get_bd_pins proc_sys_reset_100MHz/peripheral_aresetn]
  connect_bd_net -net proc_sys_reset_108MHz_peripheral_reset [get_bd_pins proc_sys_reset_108MHz/peripheral_reset] [get_bd_pins python1300_receiver_color/reset]
  connect_bd_net -net proc_sys_reset_150MHz_interconnect_aresetn [get_bd_pins axi_ic_processing_system7_0_M_AXI_GP1/ARESETN] [get_bd_pins axi_ic_processing_system7_0_M_AXI_GP1/M00_ARESETN] [get_bd_pins axi_ic_processing_system7_0_M_AXI_GP1/M01_ARESETN] [get_bd_pins axi_ic_processing_system7_0_M_AXI_GP1/M02_ARESETN] [get_bd_pins axi_ic_processing_system7_0_M_AXI_GP1/S00_ARESETN] [get_bd_pins axi_ic_processing_system7_0_S_AXI_HP2/ARESETN] [get_bd_pins axi_ic_processing_system7_0_S_AXI_HP2/M00_ARESETN] [get_bd_pins axi_ic_processing_system7_0_S_AXI_HP2/S00_ARESETN] [get_bd_pins axi_ic_processing_system7_0_S_AXI_HP2/S01_ARESETN] [get_bd_pins axi_mem_intercon/ARESETN] [get_bd_pins proc_sys_reset_150MHz/interconnect_aresetn]
  connect_bd_net -net proc_sys_reset_50MHz_interconnect_aresetn [get_bd_pins proc_sys_reset_50MHz/interconnect_aresetn] [get_bd_pins processing_system7_0_axi_periph/ARESETN]
  connect_bd_net -net proc_sys_reset_50MHz_peripheral_aresetn [get_bd_pins axi_vdma_0/axi_resetn] [get_bd_pins fmc2_imageon_iic/s_axi_aresetn] [get_bd_pins imageon_hdmi_out/axi_lite_resetn] [get_bd_pins mutex_0/S0_AXI_ARESETN] [get_bd_pins onsemi_python_spi_0/s00_axi_aresetn] [get_bd_pins proc_sys_reset_50MHz/peripheral_aresetn] [get_bd_pins processing_system7_0_axi_periph/M00_ARESETN] [get_bd_pins processing_system7_0_axi_periph/M01_ARESETN] [get_bd_pins processing_system7_0_axi_periph/M02_ARESETN] [get_bd_pins processing_system7_0_axi_periph/M03_ARESETN] [get_bd_pins processing_system7_0_axi_periph/M04_ARESETN] [get_bd_pins processing_system7_0_axi_periph/M05_ARESETN] [get_bd_pins processing_system7_0_axi_periph/S00_ARESETN] [get_bd_pins python1300_receiver_color/s00_axi_aresetn]
  connect_bd_net -net proc_sys_reset_mb_mb_reset [get_bd_pins microblaze_0/Reset] [get_bd_pins microblaze_0_axi_intc/processor_rst] [get_bd_pins proc_sys_reset_mb/mb_reset]
  connect_bd_net -net processing_system7_0_FCLK_CLK0 [get_bd_pins axi_vdma_0/s_axi_lite_aclk] [get_bd_pins clk_wiz_1/clk_in1] [get_bd_pins clk_wiz_108MHz/clk_in1] [get_bd_pins fmc2_imageon_iic/s_axi_aclk] [get_bd_pins imageon_hdmi_out/axi_lite_clk] [get_bd_pins mutex_0/S0_AXI_ACLK] [get_bd_pins onsemi_python_spi_0/s00_axi_aclk] [get_bd_pins proc_sys_reset_50MHz/slowest_sync_clk] [get_bd_pins processing_system7_0/FCLK_CLK0] [get_bd_pins processing_system7_0/M_AXI_GP0_ACLK] [get_bd_pins processing_system7_0_axi_periph/ACLK] [get_bd_pins processing_system7_0_axi_periph/M00_ACLK] [get_bd_pins processing_system7_0_axi_periph/M01_ACLK] [get_bd_pins processing_system7_0_axi_periph/M02_ACLK] [get_bd_pins processing_system7_0_axi_periph/M03_ACLK] [get_bd_pins processing_system7_0_axi_periph/M04_ACLK] [get_bd_pins processing_system7_0_axi_periph/M05_ACLK] [get_bd_pins processing_system7_0_axi_periph/S00_ACLK] [get_bd_pins python1300_receiver_color/s00_axi_aclk]
  connect_bd_net -net processing_system7_0_FCLK_CLK1 [get_bd_pins processing_system7_0/FCLK_CLK1] [get_bd_pins python1300_receiver_color/clk200]
  connect_bd_net -net processing_system7_0_FCLK_RESET0_N [get_bd_pins clk_wiz_1/resetn] [get_bd_pins clk_wiz_108MHz/resetn] [get_bd_pins proc_sys_reset_100MHz/ext_reset_in] [get_bd_pins proc_sys_reset_108MHz/ext_reset_in] [get_bd_pins proc_sys_reset_120MHz/ext_reset_in] [get_bd_pins proc_sys_reset_150MHz/ext_reset_in] [get_bd_pins proc_sys_reset_50MHz/ext_reset_in] [get_bd_pins proc_sys_reset_75MHz/ext_reset_in] [get_bd_pins proc_sys_reset_mb/ext_reset_in] [get_bd_pins processing_system7_0/FCLK_RESET0_N]
  connect_bd_net -net processing_system7_0_GPIO_O [get_bd_pins processing_system7_0/GPIO_O] [get_bd_pins xlslice_0/Din]
  connect_bd_net -net rx_1 [get_bd_ports uart_pmod_tx] [get_bd_pins axi_uartlite_0/rx]
  connect_bd_net -net sobel_filter_htile1_0_if_ap_iscalar_0_dout [get_bd_pins sobel_filter_htile1_0/rows] [get_bd_pins sobel_filter_htile1_0_if/ap_iscalar_0_dout]
  connect_bd_net -net sobel_filter_htile1_0_if_aresetn [get_bd_pins sobel_filter_htile1_0/ap_rst_n] [get_bd_pins sobel_filter_htile1_0_if/aresetn]
  connect_bd_net -net xlconcat_0_dout [get_bd_pins processing_system7_0/IRQ_F2P] [get_bd_pins xlconcat_0/dout]
  connect_bd_net -net xlconstant_0_dout [get_bd_pins bce_fp12_1x8_0_axiw_0/bce_btn4b] [get_bd_pins bce_fp12_1x8_0_axiw_0/bce_dip4b] [get_bd_pins xlconstant_0/dout]
  connect_bd_net -net xlconstant_1_dout [get_bd_pins bce_fp12_1x8_0_axiw_0/bce_gpi8b] [get_bd_pins xlconstant_1/dout]
  connect_bd_net -net xlslice_0_Dout [get_bd_pins proc_sys_reset_mb/aux_reset_in] [get_bd_pins xlslice_0/Dout]

  # Create address segments
  create_bd_addr_seg -range 0x40000000 -offset 0x0 [get_bd_addr_spaces axi_vdma_0/Data_MM2S] [get_bd_addr_segs processing_system7_0/S_AXI_HP0/HP0_DDR_LOWOCM] SEG_processing_system7_0_HP0_DDR_LOWOCM
  create_bd_addr_seg -range 0x40000000 -offset 0x0 [get_bd_addr_spaces axi_vdma_0/Data_S2MM] [get_bd_addr_segs processing_system7_0/S_AXI_HP0/HP0_DDR_LOWOCM] SEG_processing_system7_0_HP0_DDR_LOWOCM
  create_bd_addr_seg -range 0x40000000 -offset 0x0 [get_bd_addr_spaces dm_0/Data_MM2S] [get_bd_addr_segs processing_system7_0/S_AXI_HP2/HP2_DDR_LOWOCM] SEG_processing_system7_0_HP2_DDR_LOWOCM
  create_bd_addr_seg -range 0x40000000 -offset 0x0 [get_bd_addr_spaces dm_1/Data_S2MM] [get_bd_addr_segs processing_system7_0/S_AXI_HP2/HP2_DDR_LOWOCM] SEG_processing_system7_0_HP2_DDR_LOWOCM
  create_bd_addr_seg -range 0x10000 -offset 0x41C00000 [get_bd_addr_spaces microblaze_0/Data] [get_bd_addr_segs axi_timer_0/S_AXI/Reg] SEG_axi_timer_0_Reg
  create_bd_addr_seg -range 0x10000 -offset 0x40600000 [get_bd_addr_spaces microblaze_0/Data] [get_bd_addr_segs axi_uartlite_0/S_AXI/Reg] SEG_axi_uartlite_0_Reg
  create_bd_addr_seg -range 0x100000 -offset 0x44A00000 [get_bd_addr_spaces microblaze_0/Data] [get_bd_addr_segs bce_fp12_1x8_0_axiw_0/s_axi/reg0] SEG_bce_fp12_1x8_0_axiw_0_reg0
  create_bd_addr_seg -range 0x10000 -offset 0x80000000 [get_bd_addr_spaces microblaze_0/Data] [get_bd_addr_segs microblaze_0_axi_intc/s_axi/Reg] SEG_microblaze_0_axi_intc_Reg
  create_bd_addr_seg -range 0x10000 -offset 0x43400000 [get_bd_addr_spaces microblaze_0/Data] [get_bd_addr_segs mutex_0/S1_AXI/S1_AXI_Reg] SEG_mutex_0_S1_AXI_Reg
  create_bd_addr_seg -range 0x40000000 -offset 0x0 [get_bd_addr_spaces microblaze_0/Data] [get_bd_addr_segs processing_system7_0/S_AXI_HP1/HP1_DDR_LOWOCM] SEG_processing_system7_0_HP1_DDR_LOWOCM
  create_bd_addr_seg -range 0x40000000 -offset 0x0 [get_bd_addr_spaces microblaze_0/Instruction] [get_bd_addr_segs processing_system7_0/S_AXI_HP1/HP1_DDR_LOWOCM] SEG_processing_system7_0_HP1_DDR_LOWOCM
  create_bd_addr_seg -range 0x10000 -offset 0x43000000 [get_bd_addr_spaces processing_system7_0/Data] [get_bd_addr_segs axi_vdma_0/S_AXI_LITE/Reg] SEG_axi_vdma_0_Reg
  create_bd_addr_seg -range 0x10000 -offset 0x80400000 [get_bd_addr_spaces processing_system7_0/Data] [get_bd_addr_segs dm_0/S_AXI_LITE/Reg] SEG_dm_0_Reg
  create_bd_addr_seg -range 0x10000 -offset 0x80410000 [get_bd_addr_spaces processing_system7_0/Data] [get_bd_addr_segs dm_1/S_AXI_LITE/Reg] SEG_dm_1_Reg
  create_bd_addr_seg -range 0x10000 -offset 0x41600000 [get_bd_addr_spaces processing_system7_0/Data] [get_bd_addr_segs fmc2_imageon_iic/S_AXI/Reg] SEG_fmc2_imageon_iic_Reg
  create_bd_addr_seg -range 0x10000 -offset 0x43600000 [get_bd_addr_spaces processing_system7_0/Data] [get_bd_addr_segs mutex_0/S0_AXI/S0_AXI_Reg] SEG_mutex_0_S0_AXI_Reg
  create_bd_addr_seg -range 0x10000 -offset 0x43C10000 [get_bd_addr_spaces processing_system7_0/Data] [get_bd_addr_segs onsemi_python_spi_0/S00_AXI/Reg] SEG_onsemi_python_spi_0_Reg
  create_bd_addr_seg -range 0x10000 -offset 0x43C20000 [get_bd_addr_spaces processing_system7_0/Data] [get_bd_addr_segs python1300_receiver_color/onsemi_vita_cam_0/S00_AXI/Reg] SEG_onsemi_vita_cam_0_Reg
  create_bd_addr_seg -range 0x10000 -offset 0x83C00000 [get_bd_addr_spaces processing_system7_0/Data] [get_bd_addr_segs sobel_filter_htile1_0_if/S_AXI/Reg] SEG_sobel_filter_htile1_0_if_Reg
  create_bd_addr_seg -range 0x10000 -offset 0x43C00000 [get_bd_addr_spaces processing_system7_0/Data] [get_bd_addr_segs imageon_hdmi_out/v_tc_0/ctrl/Reg] SEG_v_tc_0_Reg

  # Perform GUI Layout
  regenerate_bd_layout -layout_string {
   DisplayTieOff: "1",
   guistr: "# # String gsaved with Nlview 6.5.5  2015-06-26 bk=1.3371 VDI=38 GEI=35 GUI=JA:1.6
#  -string -flagsOSRD
preplace port IO_PYTHON_SPI -pg 1 -y 3020 -defaultsOSRD
preplace port DDR -pg 1 -y 2210 -defaultsOSRD
preplace port fmc_imageon_iic -pg 1 -y 2870 -defaultsOSRD
preplace port uart_pmod_rx -pg 1 -y 1990 -defaultsOSRD
preplace port IO_PYTHON_CAM -pg 1 -y 3050 -defaultsOSRD
preplace port FIXED_IO -pg 1 -y 2230 -defaultsOSRD
preplace port fmc_hdmio_io -pg 1 -y 2730 -defaultsOSRD
preplace port uart_pmod_tx -pg 1 -y 1960 -defaultsOSRD
preplace portBus fmc_imageon_iic_rst_n -pg 1 -y 2910 -defaultsOSRD
preplace inst proc_sys_reset_108MHz -pg 1 -lvl 4 -y 2480 -defaultsOSRD
preplace inst proc_sys_reset_150MHz -pg 1 -lvl 4 -y 2300 -defaultsOSRD
preplace inst proc_sys_reset_100MHz -pg 1 -lvl 3 -y 1860 -defaultsOSRD -resize 280 140
preplace inst xlslice_0 -pg 1 -lvl 4 -y 2180 -defaultsOSRD -orient R180
preplace inst fmc2_imageon_iic -pg 1 -lvl 8 -y 2890 -defaultsOSRD
preplace inst axi_vdma_0 -pg 1 -lvl 6 -y 2510 -defaultsOSRD
preplace inst xlconstant_0 -pg 1 -lvl 4 -y 160 -defaultsOSRD
preplace inst axi_mem_intercon_1 -pg 1 -lvl 7 -y 1840 -defaultsOSRD
preplace inst xlconstant_1 -pg 1 -lvl 4 -y 1030 -defaultsOSRD
preplace inst proc_sys_reset_120MHz -pg 1 -lvl 4 -y 2050 -defaultsOSRD -resize 280 140
preplace inst bce_fp12_1x8_0_axiw_0 -pg 1 -lvl 5 -y 490 -defaultsOSRD
preplace inst proc_sys_reset_75MHz -pg 1 -lvl 3 -y 2140 -defaultsOSRD -resize 280 140
preplace inst microblaze_0_axi_periph -pg 1 -lvl 4 -y 1420 -defaultsOSRD
preplace inst axi_timer_0 -pg 1 -lvl 5 -y 1510 -defaultsOSRD
preplace inst xlconcat_0 -pg 1 -lvl 7 -y 2520 -defaultsOSRD
preplace inst microblaze_0_xlconcat -pg 1 -lvl 4 -y 1680 -defaultsOSRD
preplace inst util_vector_logic_1 -pg 1 -lvl 2 -y 2190 -defaultsOSRD
preplace inst proc_sys_reset_mb -pg 1 -lvl 4 -y 1860 -defaultsOSRD -resize 280 140
preplace inst clk_wiz_108MHz -pg 1 -lvl 1 -y 2270 -defaultsOSRD
preplace inst microblaze_0_axi_intc -pg 1 -lvl 5 -y 1720 -defaultsOSRD
preplace inst mdm_1 -pg 1 -lvl 5 -y 2060 -defaultsOSRD
preplace inst bce_fp12_1x8_0_dsp_0 -pg 1 -lvl 4 -y 540 -defaultsOSRD
preplace inst onsemi_python_spi_0 -pg 1 -lvl 8 -y 3020 -defaultsOSRD
preplace inst proc_sys_reset_50MHz -pg 1 -lvl 3 -y 2660 -defaultsOSRD
preplace inst mutex_0 -pg 1 -lvl 5 -y 2230 -defaultsOSRD
preplace inst imageon_hdmi_out -pg 1 -lvl 8 -y 2730 -defaultsOSRD
preplace inst python1300_receiver_color -pg 1 -lvl 5 -y 2490 -defaultsOSRD
preplace inst microblaze_0 -pg 1 -lvl 6 -y 1750 -defaultsOSRD
preplace inst axi_uartlite_0 -pg 1 -lvl 5 -y 1940 -defaultsOSRD
preplace inst clk_wiz_1 -pg 1 -lvl 1 -y 2080 -defaultsOSRD
preplace inst axi_mem_intercon -pg 1 -lvl 7 -y 2320 -defaultsOSRD
preplace inst processing_system7_0_axi_periph -pg 1 -lvl 4 -y 2830 -defaultsOSRD
preplace inst processing_system7_0 -pg 1 -lvl 8 -y 2350 -defaultsOSRD
preplace netloc microblaze_0_axi_periph_M02_AXI 1 4 1 1470
preplace netloc axi_vdma_0_M_AXI_MM2S 1 6 1 2640
preplace netloc clk_wiz_148_5_locked 1 1 1 200
preplace netloc bce_fp12_1x8_0_axiw_0_mem_bce_dfroma7 1 3 3 950 20 NJ 20 2100
preplace netloc bce_fp12_1x8_0_dsp_0_mem_bce_dtoa4 1 4 1 N
preplace netloc bce_fp12_1x8_0_axiw_0_mem_bce_dfromb1 1 3 3 780 980 NJ 990 2020
preplace netloc proc_sys_reset_108MHz_peripheral_reset 1 4 1 1460
preplace netloc proc_sys_reset_mb_mb_reset 1 4 2 1510 1820 NJ
preplace netloc bce_fp12_1x8_0_axiw_0_mem_bce_dfroma8 1 3 3 970 110 NJ 980 2030
preplace netloc bce_fp12_1x8_0_dsp_0_mem_bce_dtoa5 1 4 1 N
preplace netloc bce_fp12_1x8_0_axiw_0_mem_bce_dfromb2 1 3 3 960 70 NJ 1000 2010
preplace netloc axi_timer_0_interrupt 1 3 3 970 1210 NJ 1210 1940
preplace netloc bce_fp12_1x8_0_dsp_0_mem_bce_dtoa6 1 4 1 N
preplace netloc bce_fp12_1x8_0_axiw_0_mem_bce_dfromb3 1 3 3 950 920 NJ 1010 2000
preplace netloc processing_system7_0_FIXED_IO 1 8 1 NJ
preplace netloc microblaze_0_axi_periph_M03_AXI 1 4 1 1450
preplace netloc bce_fp12_1x8_0_dsp_0_mem_bce_dtoa7 1 4 1 N
preplace netloc bce_fp12_1x8_0_axiw_0_mem_bce_dfromb4 1 3 3 810 1080 NJ 1070 2200
preplace netloc microblaze_0_axi_periph_M01_AXI 1 4 1 1500
preplace netloc axi_vdma_0_M_AXI_S2MM 1 6 1 2650
preplace netloc bce_fp12_1x8_0_dsp_0_mem_bce_dtoa8 1 4 1 N
preplace netloc bce_fp12_1x8_0_axiw_0_mem_bce_dfromb5 1 3 3 930 970 NJ 1020 1980
preplace netloc bce_fp12_1x8_0_axiw_0_mem_bce_op 1 3 3 940 1160 NJ 1160 2070
preplace netloc bce_fp12_1x8_0_dsp_0_mem_bce_dtoz1 1 4 1 N
preplace netloc bce_fp12_1x8_0_axiw_0_mem_bce_we 1 3 3 980 910 NJ 1050 1940
preplace netloc bce_fp12_1x8_0_axiw_0_mem_bce_dfromb6 1 3 3 870 1090 NJ 1080 2180
preplace netloc axi_iic_0_IIC 1 8 1 NJ
preplace netloc axi_vdma_0_M_AXIS_MM2S 1 6 2 NJ 2670 N
preplace netloc proc_sys_reset_50MHz_interconnect_aresetn 1 3 1 760
preplace netloc bce_fp12_1x8_0_dsp_0_mem_bce_dtoz2 1 4 1 N
preplace netloc bce_fp12_1x8_0_axiw_0_mem_bce_dfromb7 1 3 3 820 1110 NJ 1110 2190
preplace netloc axi_uartlite_0_tx 1 5 4 NJ 1950 NJ 1990 NJ 1990 NJ
preplace netloc microblaze_0_intc_axi 1 4 1 1510
preplace netloc microblaze_0_M_AXI_IC 1 6 1 N
preplace netloc bce_fp12_1x8_0_dsp_0_mem_bce_dtoz3 1 4 1 N
preplace netloc bce_fp12_1x8_0_axiw_0_mem_bce_dfromb8 1 3 3 920 1100 NJ 1090 2140
preplace netloc xlconcat_0_dout 1 7 1 NJ
preplace netloc bce_fp12_1x8_0_dsp_0_mem_bce_dtoz4 1 4 1 N
preplace netloc bce_fp12_1x8_0_dsp_0_mem_bce_dtoz5 1 4 1 N
preplace netloc bce_fp12_1x8_0_dsp_0_mem_bce_dtoz6 1 4 1 N
preplace netloc bce_fp12_1x8_0_dsp_0_mem_bce_dtoz7 1 4 1 N
preplace netloc processing_system7_0_DDR 1 8 1 NJ
preplace netloc clk_wiz_148_5_clk_out1 1 1 7 NJ 2260 NJ 2260 780 2570 1440 2680 NJ 2680 NJ 2680 NJ
preplace netloc proc_sys_reset_50MHz_peripheral_aresetn 1 3 5 850 2610 1580 2620 2200 2630 NJ 2630 2990
preplace netloc bce_fp12_1x8_0_dsp_0_mem_bce_dtoz8 1 4 1 N
preplace netloc axi_iic_0_gpo 1 8 1 NJ
preplace netloc bce_fp12_1x8_0_dsp_0_mem_bce_wea 1 4 1 N
preplace netloc bce_fp12_1x8_0_dsp_0_mem_bce_dtob1 1 4 1 N
preplace netloc bce_fp12_1x8_0_dsp_0_mem_bce_web 1 4 1 N
preplace netloc xlconstant_1_dout 1 4 1 NJ
preplace netloc bce_fp12_1x8_0_dsp_0_mem_bce_dtob2 1 4 1 N
preplace netloc processing_system7_0_axi_periph_M05_AXI 1 4 4 NJ 2880 NJ 2880 NJ 2880 2980
preplace netloc microblaze_0_interrupt 1 5 1 N
preplace netloc bce_fp12_1x8_0_dsp_0_mem_bce_dtob3 1 4 1 N
preplace netloc processing_system7_0_FCLK_RESET0_N 1 0 9 20 1990 NJ 1990 420 1770 810 2590 NJ 2650 NJ 2650 NJ 2610 NJ 2610 3470
preplace netloc mdm_1_debug_sys_rst 1 2 4 430 1620 NJ 1620 NJ 1620 1960
preplace netloc bce_fp12_1x8_0_dsp_0_mem_bce_dtob4 1 4 1 N
preplace netloc bce_fp12_1x8_0_dsp_0_mem_bce_dtob5 1 4 1 N
preplace netloc processing_system7_0_axi_periph_M03_AXI 1 4 1 1500
preplace netloc processing_system7_0_axi_periph_M02_AXI 1 4 2 NJ 2660 2050
preplace netloc bce_fp12_1x8_0_dsp_0_mem_bce_dtob6 1 4 1 N
preplace netloc bce_fp12_1x8_0_dsp_0_mem_bce_atoz 1 4 1 N
preplace netloc bce_fp12_1x8_0_dsp_0_mem_bce_dtob7 1 4 1 N
preplace netloc axis_resetn_1 1 4 4 1470 2340 NJ 2340 2680 2570 NJ
preplace netloc xlslice_0_Dout 1 3 1 980
preplace netloc proc_sys_reset_150MHz_interconnect_aresetn 1 4 3 NJ 2330 NJ 2320 2660
preplace netloc microblaze_0_Clk 1 1 7 NJ 1820 400 1760 930 1180 1520 1830 2170 1830 2650 1690 NJ
preplace netloc bce_fp12_1x8_0_dsp_0_mem_bce_dtob8 1 4 1 N
preplace netloc bce_fp12_1x8_0_axiw_0_mem_bce_dfromz1 1 3 3 880 1120 NJ 1120 2170
preplace netloc bce_fp12_1x8_0_axiw_0_mem_bce_dfromz2 1 3 3 890 1130 NJ 1130 2160
preplace netloc bce_fp12_1x8_0_axiw_0_mem_bce_dfromz3 1 3 3 900 1140 NJ 1140 2150
preplace netloc onsemi_python_spi_0_IO_SPI_OUT 1 8 1 NJ
preplace netloc bce_fp12_1x8_0_axiw_0_mem_bce_dfromz4 1 3 3 830 30 NJ 30 2090
preplace netloc processing_system7_0_axi_periph_M01_AXI 1 4 4 NJ 2690 NJ 2690 NJ 2690 N
preplace netloc clk_wiz_1_locked1 1 1 1 190
preplace netloc bce_fp12_1x8_0_axiw_0_mem_bce_dfromz5 1 3 3 840 40 NJ 40 2080
preplace netloc rx_1 1 0 6 NJ 1960 NJ 1960 NJ 1960 NJ 1960 NJ 2120 1950
preplace netloc bce_fp12_1x8_0_axiw_0_mem_bce_dfromz6 1 3 3 850 50 NJ 50 2070
preplace netloc processing_system7_0_FCLK_CLK0 1 0 9 30 2170 NJ 2130 400 2570 770 2580 1560 2630 2150 2660 NJ 2660 3020 2590 3480
preplace netloc clk_wiz_1_locked 1 2 2 410 2050 860
preplace netloc bce_fp12_1x8_0_axiw_0_mem_bce_i_lo 1 3 3 970 900 NJ 1040 1950
preplace netloc bce_fp12_1x8_0_axiw_0_mem_bce_dfromz7 1 3 3 910 80 NJ 1030 1960
preplace netloc imageon_hdmi_out_HDMI_vid_out 1 8 1 NJ
preplace netloc microblaze_0_debug 1 5 1 2040
preplace netloc processing_system7_0_FCLK_CLK1 1 4 5 1600 2640 NJ 2640 NJ 2580 NJ 2580 3460
preplace netloc bce_fp12_1x8_0_axiw_0_mem_bce_dfromz8 1 3 3 910 1150 NJ 1150 2130
preplace netloc microblaze_0_axi_dp 1 3 4 980 1220 NJ 1220 NJ 1220 2640
preplace netloc proc_sys_reset_100MHz_interconnect_aresetn 1 3 4 870 1770 NJ 1840 NJ 1840 2640
preplace netloc processing_system7_0_axi_periph_M00_AXI 1 4 4 NJ 2780 NJ 2780 NJ 2780 3000
preplace netloc clk_wiz_1_clk_out1 1 1 7 NJ 2040 NJ 2040 910 1950 1450 2350 1980 2350 2670 2470 3040
preplace netloc clk_wiz_1_clk_out2 1 1 4 NJ 2010 NJ 2010 760 1170 1470
preplace netloc v_cresample_0_video_out 1 5 1 2110
preplace netloc bce_fp12_1x8_0_dsp_0_mem_bce_done 1 4 1 N
preplace netloc microblaze_0_axi_periph_M04_AXI 1 4 1 N
preplace netloc axi_mem_intercon_1_M00_AXI 1 7 1 3020
preplace netloc clk_wiz_1_clk_out4 1 1 2 NJ 2100 N
preplace netloc axi_uartlite_0_interrupt 1 3 3 980 1740 NJ 1860 1940
preplace netloc processing_system7_0_M_AXI_GP0 1 3 6 960 1200 NJ 1200 NJ 1200 NJ 1200 NJ 1200 3480
preplace netloc bce_fp12_1x8_0_dsp_0_mem_bce_atoa 1 4 1 N
preplace netloc bce_fp12_1x8_0_axiw_0_mem_bce_dfroma1 1 3 3 770 940 NJ 940 2120
preplace netloc xlconstant_0_dout 1 4 1 1440
preplace netloc bce_fp12_1x8_0_dsp_0_mem_bce_atob 1 4 1 N
preplace netloc bce_fp12_1x8_0_axiw_0_mem_bce_dfroma2 1 3 3 860 930 NJ 930 1990
preplace netloc bce_fp12_1x8_0_dsp_0_mem_bce_wez 1 4 1 N
preplace netloc microblaze_0_M_AXI_DC 1 6 1 N
preplace netloc axi_mem_intercon_M00_AXI 1 7 1 N
preplace netloc bce_fp12_1x8_0_axiw_0_mem_bce_dfroma3 1 3 3 790 950 NJ 950 2060
preplace netloc IO_CAM_IN_1 1 0 5 NJ 2390 NJ 2390 NJ 2390 NJ 2390 NJ
preplace netloc processing_system7_0_GPIO_O 1 4 5 NJ 2130 NJ 2120 NJ 2120 NJ 2120 3460
preplace netloc microblaze_0_intr 1 4 1 1510
preplace netloc bce_fp12_1x8_0_axiw_0_mem_bce_dfroma4 1 3 3 800 960 NJ 960 2050
preplace netloc bce_fp12_1x8_0_dsp_0_mem_bce_dtoa1 1 4 1 N
preplace netloc processing_system7_0_axi_periph_M04_AXI 1 4 1 1530
preplace netloc bce_fp12_1x8_0_axiw_0_mem_bce_dfroma5 1 3 3 980 100 NJ 970 2040
preplace netloc bce_fp12_1x8_0_dsp_0_mem_bce_dtoa2 1 4 1 N
preplace netloc proc_sys_reset_100MHz_peripheral_aresetn 1 3 4 790 1190 1530 1850 NJ 1850 2640
preplace netloc bce_fp12_1x8_0_axiw_0_mem_bce_i_hi 1 3 3 960 890 NJ 1060 1970
preplace netloc bce_fp12_1x8_0_axiw_0_mem_bce_dfroma6 1 3 3 930 10 NJ 10 2110
preplace netloc bce_fp12_1x8_0_dsp_0_mem_bce_dtoa3 1 4 1 N
levelinfo -pg 1 0 110 310 600 1220 1770 2420 2830 3250 3500 -top 0 -bot 3100
",
}

  # Restore current instance
  current_bd_instance $oldCurInst

  save_bd_design
}
# End of create_root_design()


##################################################################
# MAIN FLOW
##################################################################

create_root_design ""


